<?php
/**
 * Narihealth WordPress Theme.
 * @package NarihealthTheme
 * @version 1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// included plugins current versions
define( 'NARIHEALTH_CORE_PLUGIN_CURRENT_VERSION', '1.0.0' );
define( 'NARIHEALTH_ELEMENTOR_ADDON_PLUGIN_CURRENT_VERSION', '1.0.1' );

if ( ! function_exists( 'narihealth_theme_setup' ) ) :
/**
 * Theme setup
 */
function narihealth_theme_setup() {
	
	// Makes theme available for translation.
	load_theme_textdomain( 'narihealth', get_template_directory() . '/languages' );
	
	// Document title
	add_theme_support( 'title-tag' );
	
	// Logo support
	add_theme_support( 'custom-logo' );
	
	// Custom background
	add_theme_support( 'custom-background' );
	
    // Switches default core markup for below
	add_theme_support( 'html5', array( 'comment-form', 'comment-list', 'gallery', 'caption', 'style', 'script', 'navigation-widgets', ) );

    // Adds thumbnail support
	add_theme_support( 'post-thumbnails' );
	
	// Set the default content width.
	$GLOBALS['content_width'] = 1320;
	
    // Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	
	// wp_nav_menu() locations
    register_nav_menus( array(
        'primary_menu'		=> 'Primary Menu',
    ) );  
	
	// Adds theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );
	
	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );
	
	// editor style
	add_editor_style( 'assets/css/dtr-editor-style.css' );
	
	// Add support for responsive embedded content.
	add_theme_support( 'responsive-embeds' );
	
	// Add support for Editor color palette.
	$dark   = '#262628';
	$white 	= '#ffffff';
	$gray   = '#f4f3ff';
	$dark_blue  = '#27115f';
	$dark_pink  = '#c11574';
	$light_blue	= '#f4f3ff';
    $light_pink	= '#efc4dc';

	add_theme_support(
		'editor-color-palette',
		array(
			array(
				'name'  => esc_html__( 'Dark', 'narihealth' ),
				'slug'  => 'dark',
				'color' => $dark,
			),
			array(
				'name'  => esc_html__( 'White', 'narihealth' ),
				'slug'  => 'white',
				'color' => $white,
			),
			array(
				'name'  => esc_html__( 'Gray', 'narihealth' ),
				'slug'  => 'gray',
				'color' => $gray,
			),
			array(
				'name'  => esc_html__( 'Dark Blue', 'narihealth' ),
				'slug'  => 'dark-blue',
				'color' => $dark_blue,
			),
			array(
				'name'  => esc_html__( 'Dark Pink', 'narihealth' ),
				'slug'  => 'dark-pink',
				'color' => $dark_pink,
			),
			array(
				'name'  => esc_html__( 'Light Blue', 'narihealth' ),
				'slug'  => 'light-blue',
				'color' => $light_blue,
			),
            array(
				'name'  => esc_html__( 'Light Pink', 'narihealth' ),
				'slug'  => 'light-pink',
				'color' => $light_pink,
			),
		)
	);
				
	// Add custom editor font sizes.
	add_theme_support(
		'editor-font-sizes',
		array(
			array(
				'name'      => esc_html__( 'Extra small', 'narihealth' ),
				'shortName' => esc_html_x( 'XS', 'Font size', 'narihealth' ),
				'size'      => 10,
				'slug'      => 'extra-small',
			),
			array(
				'name'      => esc_html__( 'Small', 'narihealth' ),
				'shortName' => esc_html_x( 'S', 'Font size', 'narihealth' ),
				'size'      => 12,
				'slug'      => 'small',
			),
			array(
				'name'      => esc_html__( 'Normal', 'narihealth' ),
				'shortName' => esc_html_x( 'M', 'Font size', 'narihealth' ),
				'size'      => 20,
				'slug'      => 'normal',
			),
			array(
				'name'      => esc_html__( 'Large', 'narihealth' ),
				'shortName' => esc_html_x( 'L', 'Font size', 'narihealth' ),
				'size'      => 24,
				'slug'      => 'large',
			),
			array(
				'name'      => esc_html__( 'Extra large', 'narihealth' ),
				'shortName' => esc_html_x( 'XL', 'Font size', 'narihealth' ),
				'size'      => 40,
				'slug'      => 'extra-large',
			),
		)
	); // Add custom editor font sizes.

}
endif; // narihealth_theme_setup
add_action( 'after_setup_theme', 'narihealth_theme_setup' );

/**
 * Enqueue Plugins Scripts and Styles
 *
 */
if ( ! function_exists( 'narihealth_plugin_scripts_styles' ) ) :
function narihealth_plugin_scripts_styles() {
	
	// enqueue scripts
	wp_enqueue_script( 'jquery-easing', get_template_directory_uri() . '/assets/js/jquery.easing.js', array('jquery'), '1.3.0', true );
	wp_enqueue_script( 'imagesloaded' );
	wp_enqueue_script( 'masonry' );
	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/assets/js/isotope.js', array('jquery'), '3.0.6', true );
	wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/assets/js/jquery.slicknav.js', array('jquery'), '1.0.10', true );
	wp_enqueue_script( 'hoverIntent', get_template_directory_uri() . '/assets/js/hoverIntent.js', array('jquery'), '1.10.1', true );
	wp_enqueue_script( 'superfish', get_template_directory_uri() . '/assets/js/superfish.js', array('jquery'), '1.7.10', true );
	
	// enqueue styles
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
	wp_enqueue_style( 'iconfont', get_template_directory_uri() . '/fonts/iconfont.css' );
	
	// comments
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
endif; 
add_action( 'wp_enqueue_scripts', 'narihealth_plugin_scripts_styles' );
// narihealth_plugin_scripts_styles ends

/**
 * Enqueue Custom Scripts and Styles
 *
 */
if ( ! function_exists( 'narihealth_custom_scripts_styles' ) ) :
function narihealth_custom_scripts_styles() {
	
	// enqueue scripts
	wp_enqueue_script( 'narihealth-custom-js', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '1.0.0', true );
	
	// enqueue main stylesheet and colors
	wp_enqueue_style( 'narihealth-style', get_stylesheet_uri() );

	if( 'header-v1' == get_theme_mod( 'narihealth_header_layout', 'header-v3' ) ) {
		wp_register_style( 'narihealth-header-v1', get_template_directory_uri() . '/assets/css/header-v1.css' );
		wp_enqueue_style( 'narihealth-header-v1' );
	} elseif ( 'header-v2' == get_theme_mod( 'narihealth_header_layout', 'header-v3' ) ) {
		wp_register_style( 'narihealth-header-v2', get_template_directory_uri() . '/assets/css/header-v2.css' );
		wp_enqueue_style( 'narihealth-header-v2' );
	} elseif ( 'header-v3' == get_theme_mod( 'narihealth_header_layout', 'header-v3' ) ) {
		wp_register_style( 'narihealth-header-v3', get_template_directory_uri() . '/assets/css/header-v3.css' );
		wp_enqueue_style( 'narihealth-header-v3' );
	} elseif ( 'header-v4' == get_theme_mod( 'narihealth_header_layout', 'header-v3' ) ) {
		wp_register_style( 'narihealth-header-v4', get_template_directory_uri() . '/assets/css/header-v4.css' );
		wp_enqueue_style( 'narihealth-header-v4' );
	} 

	// RTL support
	if ( is_rtl() ) {
 		wp_enqueue_style( 'narihealth-rtl-style', get_template_directory_uri() . '/assets/css/rtl.css' );
	}
	
	// load google fonts if no kirki
	if ( ! class_exists( 'Kirki' ) ) {
		wp_enqueue_style( 'narihealth-google-font-inter', 'https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600&display=swap', false );
		wp_register_style( 'no-kirki', get_template_directory_uri() . '/assets/css/no-kirki.css' );
		wp_enqueue_style( 'no-kirki' );
	}
	
}
endif; 
add_action( 'wp_enqueue_scripts', 'narihealth_custom_scripts_styles', 20 );
// narihealth_custom_scripts_styles ends

/**
 * Enqueue Custom Scripts and Styles Overrides
 *
 */
if ( ! function_exists( 'narihealth_custom_scripts_override' ) ) :
function narihealth_custom_scripts_override() {
	wp_enqueue_style( 'narihealth-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
}
endif; // narihealth_custom_scripts_styles
add_action( 'wp_enqueue_scripts', 'narihealth_custom_scripts_override', 40 );
// narihealth_custom_scripts_override ends

/**
 * Recommend plugins for this theme via TGMPA script
 */
if ( ! function_exists( 'narihealth_plugin_setup' ) ) :
function narihealth_plugin_setup() {
	require_once( get_template_directory() .'/includes/include-plugins.php' );
}
endif; // narihealth_plugin_setup
add_action( 'after_setup_theme', 'narihealth_plugin_setup' );

/**
 * Helper Functions
 */
require_once( get_template_directory() .'/includes/helper-functions/pagination.php' );
require_once( get_template_directory() .'/includes/helper-functions/schema-markup.php' );
require_once( get_template_directory() .'/includes/helper-functions/helper-functions.php' );
require_once( get_template_directory() .'/includes/helper-functions/blog-functions.php' );
require_once( get_template_directory() .'/includes/helper-functions/excerpt.php' );

/**
 * Customizer.
 */
require_once( get_template_directory() .'/includes/customizer/include-kirki.php' ); 
require_once( get_template_directory() .'/includes/customizer/kirki-fallback.php' ); 
require_once( get_template_directory() .'/includes/customizer/customizer.php' ); 

/**
 * Body / layout classes
 */
require_once( get_template_directory() .'/includes/body-classes.php' );
require_once( get_template_directory() .'/includes/layout.php' );
require_once( get_template_directory() .'/template-parts/page-title/page-header.php' );

/**
 * Sidebars / Widgets
 */
require_once( get_template_directory() .'/includes/widgets/sidebars.php' );

// Custom styles 
require_once ( get_template_directory() . '/includes/custom-styles.php' );

// wp blocks assets
add_filter( 'should_load_separate_core_block_assets', '__return_true' );

/**
 * One page nav walker
 */
function narihealth_one_page_nav_walker($output, $item, $depth, $args) {

	global $post;
	$front_id = get_option('page_on_front');

	if(is_object($post)) {
		
		$output = str_replace( 'http://frontpage_url/', get_permalink($front_id), $output);
		$output = str_replace( 'https://frontpage_url/', get_permalink($front_id), $output);
		$output = str_replace( get_permalink($post->ID).'#', '#', $output );

        // one page menu link
        if ( strpos( $output, '#' ) !== false ) {
            $current_url = get_permalink( $post->ID );

            if ( strpos( $output, $current_url ) !== false ) {
                $output = str_replace( $current_url . '/#', '#', $output );
            }
        }
	}
    return $output;
}
add_filter( 'walker_nav_menu_start_el', 'narihealth_one_page_nav_walker', 10, 4);

/**
 * Custom callback function for comment display
 */
if( ! function_exists('narihealth_comment' ) ) {
	function narihealth_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
		?>

<li class="post pingback">
	<p> <strong>
		<?php esc_html_e( 'Pingback:', 'narihealth' ); ?>
		</strong>
		<?php comment_author_link(); ?>
		<?php edit_comment_link( esc_html__( 'Edit', 'narihealth' ), '<span class="edit-link">', '</span>' ); ?>
	</p>
	<?php
			break;
			default :
		?>
<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
	<article id="div-comment-<?php comment_ID(); ?>" class="dtr-comment-body">
    <div class="dtr-comment-wrapper">
        <div class="dtr-comment-avatar vcard">
            <?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size']); ?>
        </div>
        <div class="dtr-comment-content">
            <div class="dtr-comment-meta-wrapper">
            	<div class="dtr-comment-meta">
                    <h5 class="dtr-comment-author">
                        <?php /* translators: %s: author. */
                            printf( wp_kses( __( '<cite class="fn custom-fn">%s</cite>', 'narihealth' ), array( 'a' => array( 'href' => array() ) ) ), get_comment_author_link() ); ?>
                    </h5>
                    <a class="dtr-comment-date" href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
                    <?php  /* translators: 1: date, 2: time. */
                        printf( esc_html__( '%1$s at %2$s', 'narihealth' ), get_comment_date(),  get_comment_time() ); ?>
                    </a>
                    <?php edit_comment_link( esc_html__( 'Edit', 'narihealth' ), '<span>', '</span>'); ?>
                    
                    </div>
                    <div class="dtr-reply dtr-link"><span class="dtr-link__text"><?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?></span>
                    </div>
            </div>
            <div class="dtr-comment-content-inner">
                <?php comment_text() ?>
                <?php if ( '0' == $comment->comment_approved ) : ?>
                <p class="comment-awaiting-moderation">
                    <?php esc_html_e( 'Your comment is awaiting moderation.', 'narihealth' ) ?>
                </p>
                <?php endif; ?>
            </div>
        </div>
    </div>
</article>
	<?php
		break;
		endswitch;
	}
} // end comment callback function

if ( ! function_exists( 'narihealth_embed_allowed_tags' ) ) :
/**
 * Allowed tags for video / audio embed
 */ 
	function narihealth_embed_allowed_tags() {	
	$narihealth_embed_allowed = array(
	'a' => array(
	'href' => array (),
	'title' => array ()),
	'b' => array(
	'style'=> array(),
	),
	);
	// iframe
	$narihealth_embed_allowed['iframe'] = array(
	'src' => array(),
	'height' => array(),
	'width' => array(),
	'frameborder' => array(),
	'allowfullscreen' => array(),
	);
	// video
	$narihealth_embed_allowed['video'] = array(
		'width' => true,
		'height' => true
	);
	// source
	$narihealth_embed_allowed['source'] = array(
		'src' => true,
		'type' => true
	);
	return $narihealth_embed_allowed;
	}
endif;

/**
 *  Conatact form 7
 */
if ( ! function_exists( 'narihealth_wpcf7_select' ) ) :
	function narihealth_wpcf7_select($html) {
	$text = esc_html__( 'Please Select...', 'narihealth' );
	$html = str_replace('---', '' . $text . '', $html);
	return $html;
	}
	add_filter('wpcf7_form_elements', 'narihealth_wpcf7_select');
endif;

/**
 * narihealth demo data import
 */
if ( ! function_exists( 'narihealth_import_data' ) ) {
	function narihealth_import_data() {
	  return array(
		array(
		  'import_file_name'             => esc_html__( 'Narihealth Demo Data', 'narihealth' ),
		  'local_import_file'            => get_template_directory() . '/includes/imports/content.xml',
		  'local_import_widget_file'     => get_template_directory() . '/includes/imports/widgets.wie',
		  'local_import_customizer_file' => get_template_directory() . '/includes/imports/customizer.dat',
		  'import_notice'                => wp_kses( __( 'Make sure all the required / recommended plugins are <strong>Installed and Activated.</strong><br><br>Please be patient...click on the Import button only once and wait, <strong>it may take - FEW - minutes.</strong><br><br>After import, <strong>error log file may get generated</strong>. Nothing to panic, go thorough file. <strong>Minor errors like some media / images / sidebar / widget Failed to import, can be ignored.</strong> Check if you have posts and pages imported fine.<br><br>Posts, pages, images, widgets, menus and other theme settings will get imported.<br><br>No existing posts, pages, categories, images, custom post types or any other data will be deleted or modified.', 'narihealth' ), array( 'strong' => array(), 'br' => array(), 'a' => array( 'href' => array(), 'title' => array(), 'target' => array() ), ) ), // import notice
		),
	  );
	}
}
add_filter( 'pt-ocdi/import_files', 'narihealth_import_data' );

// After import
if ( ! function_exists( 'narihealth_after_import_setup' ) ) {
	function narihealth_after_import_setup() {
		// set menu
		$main_menu		= get_term_by( 'name', 'Primary Menu', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary_menu'		=> $main_menu->term_id,
			)
		);
		// set home and blog page
		$front_page_id = get_page_by_path( 'home' );
		$blog_page_id  = get_page_by_path( 'blog' );
		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', $blog_page_id->ID );
	}
}
add_action( 'pt-ocdi/after_import', 'narihealth_after_import_setup' );

// Custom Header For Import
if ( ! function_exists( 'narihealth_plugin_page_setup' ) ) {
	function narihealth_plugin_page_setup( $default_settings ) {
		$default_settings['parent_slug'] = 'themes.php';
		$default_settings['page_title']  = esc_html__( 'Narihealth Demo Import', 'narihealth' );
		$default_settings['menu_title']  = esc_html__( 'Import Theme Demo Data', 'narihealth' );
		$default_settings['capability']  = 'import';
	
		return $default_settings;
	}
}
add_filter( 'pt-ocdi/plugin_page_setup', 'narihealth_plugin_page_setup' );

// Branding
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

// Import only original size images
add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717562908547';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        