<?php
/**
 * Theme helper functions
 *
 * @package NarihealthTheme
 * @version 1.0.0
 */

/**
 * Flush rewrite rules for custom post types on theme activation
 */
add_action( 'after_switch_theme', 'narihealth_rewrite_rules_flush' );
function narihealth_rewrite_rules_flush() {
     flush_rewrite_rules();
}

/**
 * Modify category widget 
 */
if ( ! function_exists( 'narihealth_categories_postcount_filter' ) ) :
	function narihealth_categories_postcount_filter ( $in ) {
	  $out = preg_replace( '/<\/a> \(([0-9]+)\)/', ' <span class="dtr-post-count">\\1</span></a>', $in );
	  return $out;
	}
	add_filter('wp_list_categories','narihealth_categories_postcount_filter');
endif;

/**
 * Wrap current page in span for wp_link_pages
 */
if ( ! function_exists( 'narihealth_wp_link_pages_wrap' ) ) :
	function narihealth_wp_link_pages_wrap( $link ) {
		if ( ctype_digit( $link ) ) {
			return '<span class="page-link-current">' . $link . '</span>';
		}
		return $link;
	}
	add_filter( 'wp_link_pages_link', 'narihealth_wp_link_pages_wrap' );
endif;

/**
 * Sanitize checkbox
 */
if ( ! function_exists( 'narihealth_sanitize_checkbox' ) ) {
	function narihealth_sanitize_checkbox( $input ) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}
} // narihealth_sanitize_checkbox

/**
 * Sanitize select
 */
if ( ! function_exists( 'narihealth_sanitize_select' ) ) {
	function narihealth_sanitize_select( $input, $setting ){
		$input = sanitize_key($input);
		$choices = $setting->manager->get_control( $setting->id )->choices;
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );                
	}
}

/**
 * Sanitize image upload
 */
if ( ! function_exists( 'narihealth_sanitize_image' ) ) {
	function narihealth_sanitize_image( $file, $setting ) {
	  
		//allowed file types
		$mimes = array(
			'jpg|jpeg|jpe' => 'image/jpeg',
			'gif'          => 'image/gif',
			'png'          => 'image/png'
		);
		  
		//check file type from file name
		$file_ext = wp_check_filetype( $file, $mimes );
		  
		//if file has a valid mime type return it, otherwise return default
		return ( $file_ext['ext'] ? $file : $setting->default );
	}
}

// core plugin update notice
if ( ! function_exists( 'narihealth_core_update_admin_notice' ) ) {
	function narihealth_core_update_admin_notice() {
		if ( is_admin() ) {
			if( !function_exists('get_plugin_data') ){
				require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
			}
			if ( !class_exists( 'dtr_narihealth_core' ) ) return;
			$narihealth_core_plugin_dir = WP_PLUGIN_DIR . '/dtr-narihealth-core/dtr-narihealth-core.php';
			$narihealth_core_plugin_data = get_plugin_data($narihealth_core_plugin_dir);
			$narihealth_core_plugin_version = $narihealth_core_plugin_data['Version'];
			if ( $narihealth_core_plugin_version < NARIHEALTH_CORE_PLUGIN_CURRENT_VERSION ) { ?>
				<div class="notice notice-error"><p><?php _e( '<strong>Important</strong> : Update Copr Core Plugin. Go To : Appearance / Install Plugins', 'narihealth' ); ?></p></div>
			<?php }
		}
	}
}
add_action( 'admin_notices', 'narihealth_core_update_admin_notice' );

// elementor addon plugin update notice
if ( ! function_exists( 'narihealth_elementor_addon_update_admin_notice' ) ) {
	function narihealth_elementor_addon_update_admin_notice() {
		if ( is_admin() ) {
			if( !function_exists('get_plugin_data') ){
				require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
			}
			if ( !class_exists( '\CoprAddons\Copr_Elementor_Addons' ) ) return;
			$narihealth_elementor_addon_plugin_dir = WP_PLUGIN_DIR . '/dtr-narihealth-elementor-addon/dtr-narihealth-elementor.php';
			$narihealth_elementor_addon_plugin_data = get_plugin_data($narihealth_elementor_addon_plugin_dir);
			$narihealth_elementor_addon_plugin_version = $narihealth_elementor_addon_plugin_data['Version'];
			if ( $narihealth_elementor_addon_plugin_version < NARIHEALTH_ELEMENTOR_ADDON_PLUGIN_CURRENT_VERSION ) { ?>
            	<div class="notice notice-error"><p><?php _e( '<strong>Important</strong> : Update Copr Elementor Addons Plugin Plugin. Go To : Appearance / Install Plugins', 'narihealth' ); ?></p></div>
			<?php }
		}
	}
}
add_action( 'admin_notices', 'narihealth_elementor_addon_update_admin_notice' );

// import Notice
if ( true == get_theme_mod( 'narihealth_demo_import_notification_enable', true ) ) { 
	if ( ! function_exists( 'narihealth_demo_import_notice' ) ) {
		function narihealth_demo_import_notice() {
			?>
			<div class="notice notice-error is-dismissible dtr-import-notice">
            	<h4><?php _e( '** Theme SetUp Guide for New Buyers **', 'narihealth' ); ?></h4>
            	<h5><?php _e( 'Step 1: Install All Required / Recommended Plugins', 'narihealth' ); ?></h5>
              <p><?php _e( 'There is a link to install plugins in below Notice OR <strong>Visit : Appearance > Install Plugins</strong>', 'narihealth' ); ?></p>
            	<h5><?php _e( 'Step 2: Import Theme Demo Data', 'narihealth' ); ?></h5>
				<p><?php _e( 'As WordPress Themes do not carry data with them...Import Demo Data to make your link look like Theme Demo.<br> <strong>Visit : Appearance > Import Theme Demo Data</strong>', 'narihealth' ); ?></h5>
                <h5><?php _e( 'Step 3: Online Help Documentation', 'narihealth' ); ?></h5>
                <p><?php _e( 'Find online help document here : <a class="button button-primary" href="https://docs.tanshcreative.com/narihealth" target="_blank">Online Help Documentation</a>', 'narihealth' ); ?></p>
                <h5><?php _e( 'Step 4: Disable this Notification', 'narihealth' ); ?></h5>
                <p><?php _e( 'If you have finished importing demo data...<strong>Permanently Disable</strong> this Demo Import and Import Plugin Install <strong>Notice</strong> ( Customizer > Misc > Demo Import Notice )', 'narihealth' ); ?></h5><br>
                <a class="button button-primary" href="<?php echo admin_url( '/customize.php?autofocus[panel]=narihealth_panel_misc&autofocus[section]=narihealth_section_demo_import_settings' ) ?>"><?php _e( 'Disable This Notice', 'narihealth' ); ?></a>
			</div>
			<?php
		}
		add_action( 'admin_notices', 'narihealth_demo_import_notice' );
	}
}

// admin styles
if ( true == get_theme_mod( 'narihealth_demo_import_notification_enable', true ) ) { 
	if ( ! function_exists( 'narihealth_import_notice_admin_css' ) ) {
		function narihealth_import_notice_admin_css() {
		  echo '<style>
			.dtr-import-notice { background-color: #f8e0ff; border-color: #f8e0ff; border-left-color: #7a37d2; color: #26142b; }
			.dtr-import-notice h4 { font-size: 1.4em; }
			.dtr-import-notice h5 { font-size: 1.2em; margin-bottom: 10px; }
			.dtr-import-notice p { font-size: 1em; }
			.dtr-import-notice .button { margin-top: 10px; }
            .wp-block-heading, .wp-block-spacer { background-color: #ddd; }
		  </style>';
		}
		add_action('admin_head', 'narihealth_import_notice_admin_css'); 
	}
}