<?php
/**
 * Paginations
 *
 * @package NarihealthTheme
 * @version 1.0.0
 */
// atributes to navigation links
if ( ! function_exists( 'narihealth_next_posts_link_attributes' ) ) {
	function narihealth_next_posts_link_attributes() {
		return 'aria-label="' . esc_attr__('Next Post','narihealth') . '"';
	}
}
add_filter('next_posts_link_attributes', 'narihealth_next_posts_link_attributes');

if ( ! function_exists( 'narihealth_prev_posts_link_attributes' ) ) {
	function narihealth_prev_posts_link_attributes() {
		return 'aria-label="' . esc_attr__('Previous Post','narihealth') . '"';
	}
}
add_filter('previous_posts_link_attributes', 'narihealth_prev_posts_link_attributes');

/**
 * Navigation : title next/prev for a single post
 */
if ( ! function_exists( 'narihealth_title_post_nav' ) ) :
	function narihealth_title_post_nav() { 
	?>
	<nav class="dtr-single-post-nav dtr-title-nav">
		<?php $prev_post = get_previous_post(); 
		$prev_nav_text	 = get_theme_mod('narihealth_prev_nav_text', esc_html__('Previous Post','narihealth')); ?>
		<div class="dtr-single-nav-prev">
        <?php if( $prev_post ) { ?>
        	<?php previous_post_link('%link','<p class="dtr-single-nav-text dtr-single-nav-prev__text has-drct">' . esc_html( $prev_nav_text ) . '</p>'); ?>
			<?php previous_post_link('%link',"<p class='dtr-single-nav-text dtr-single-nav-prev__text has-title'>%title</p>"); ?>
		<?php } ?>
		</div>
		<?php $next_post = get_next_post(); 
		$next_nav_text	 = get_theme_mod('narihealth_next_nav_text', esc_html__('Next Post','narihealth')); ?>
		<div class="dtr-single-nav-next">
        <?php if( $next_post ) { ?>
        	<?php next_post_link('%link','<p class="dtr-single-nav-text dtr-single-nav-next__text has-drct">' . esc_html( $next_nav_text ) . '</p>'); ?>
			<?php next_post_link('%link',"<p class='dtr-single-nav-text dtr-single-nav-next__text has-title'>%title</p>"); ?>
        <?php } ?>
		</div>
	</nav>
	<?php
	}
endif; // narihealth_title_post_nav

/**
 * Navigation : next/prev for a single post
 */
if ( ! function_exists( 'narihealth_post_nav' ) ) :
	function narihealth_post_nav() { 
	?>
	<nav class="dtr-single-post-nav">
		<?php $prev_post = get_previous_post(); 
		 $prev_nav_text	 = get_theme_mod('narihealth_prev_nav_text', esc_html__('Previous Post','narihealth')); ?>
		<div class="dtr-single-nav-prev">
        <?php if( $prev_post ) { ?>
			<?php previous_post_link('%link','<h6 class="dtr-single-nav-text dtr-single-nav-prev__text has-drct only-drct">' . esc_html( $prev_nav_text ) . '</h6>'); ?>
		<?php } ?>
		</div>
		<?php $next_post = get_next_post(); 
		$next_nav_text	 = get_theme_mod('narihealth_next_nav_text', esc_html__('Next Post','narihealth')); ?>
		<div class="dtr-single-nav-next">
        <?php if( $next_post ) { ?>
        	<?php next_post_link('%link','<h6 class="dtr-single-nav-text dtr-single-nav-next__text has-drct only-drct">' . esc_html( $next_nav_text ) . '</h6>'); ?>
        <?php } ?>
		</div>
	</nav>
	<?php
	}
endif; // narihealth_post_nav

/**
 * Navigation : next/prev for archives
 */
if ( ! function_exists( 'narihealth_archive_nav' ) ) :
function narihealth_archive_nav() {
	global $wp_query;
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
<nav class="dtr-archive-nav dtr-arrow-nav clearfix">
	<div class="dtr-arrow-nav__buttons-wrapper clearfix">
		<div class="dtr-arrow-nav__button dtr-arrow-nav__prev-button">
			<?php if ( get_next_posts_link() ) : ?>
			<?php next_posts_link( '<div class="dtr-arrow-nav__prev-icon"></div>' );  ?>
			<?php endif; ?>
		</div>
		<div class="dtr-arrow-nav__button dtr-arrow-nav__next-button">
			<?php if ( get_previous_posts_link() ) : ?>
			<?php previous_posts_link( '<div class="dtr-arrow-nav__next-icon"></div>' ); ?>
			<?php endif; ?>
		</div>
	</div>
</nav>
<!-- .dtr-post-nav -->
<?php
}
endif; // narihealth_archive_nav

/**
 * Pagination : Numbered 
 */
if ( ! function_exists( 'narihealth_numbered_pagination' ) ) :
    function narihealth_numbered_pagination( $query = '' ) {

        if ( ! $query ) {
            global $wp_query;
            $query = $wp_query;
        }
		
		// vars
		$total  = $query->max_num_pages;
        $big    = 999999999; // unlikely integer

		// pagination
        if ( $total > 1 ) {
		
            // Get permalink structure
            if ( get_option( 'permalink_structure' ) ) {
                if ( is_page() ) {
                    $format = 'page/%#%/';
                } else {
                    $format = '/%#%/';
                }
            } else {
                $format = '&paged=%#%';
            }

            // Get current page
            if ( $current_page = get_query_var( 'paged' ) ) {
                $current_page = $current_page;
            } elseif ( $current_page = get_query_var( 'page' ) ) {
                $current_page = $current_page;
            } else {
                $current_page = 1;
            }

            // Midsize
            $mid_size = '2';
			
            // Pagination output
            $links = paginate_links( array(
                'base'          => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
                'format'        => $format,
                'total'         => $total,
				'current'       => max( 1, $current_page ),
                'mid_size'      => $mid_size,
                'prev_next'     => false,
                'next_text'     => false,
			    'type'          => 'array'
            ) );
			
			if ( $links ) :

    echo '<ul class="dtr-archive-nav dtr-number-nav clearfix">';
    if ( get_previous_posts_link() ) :
        echo '<li class="dtr-number-nav__button dtr-number-nav__prev-arrow">';
        echo get_previous_posts_link( '<div class="dtr-number-nav__prev-icon"></div>' );
        echo '</li>';
    endif;

    echo '<li class="dtr-number-nav__button dtr-number-nav__numbers">';
    echo join( '</li><li class="dtr-number-nav__button">', $links );
    echo '</li>';

    if ( get_next_posts_link() ) :
        echo '<li class="dtr-number-nav__button dtr-number__next-arrow">';
		echo get_next_posts_link( '<div class="dtr-number-nav__next-icon"></div>' );
        echo '</li>';
    endif;
    echo '</ul>';
endif;
        }
    }
endif; // narihealth_numbered_pagination