<?php
/**
 * The Page header for archives
 *
 * @package NarihealthTheme
 * @version 1.0.0
 */
// Page header hook
if( ! function_exists( 'narihealth_default_page_header_hook' ) ) {
	function narihealth_default_page_header_hook() {
		narihealth_page_header();
	}
}
// Build Page Title
if ( ! function_exists('narihealth_page_title') ) {
	function narihealth_page_title( $page_title='' ) {
		
		if ( is_home() ) { 
			$page_title = get_theme_mod( 'narihealth_blog_title', esc_html__('Blog','narihealth') ); 
		}
		// Archives   
		elseif ( is_archive() ) {
			// category
			if ( is_category() ) {
				$page_title = sprintf( single_cat_title( '', false ) );
			// tag
			} elseif ( is_tag() ) {
        		$page_title = sprintf( single_tag_title( '', false ) );
			// Daily archive
			} elseif ( is_day() ) {
				$page_title = sprintf( get_the_date() );
			// Monthly archive
			} elseif ( is_month() ) {
				$page_title = sprintf( get_the_date( _x( 'F Y', 'monthly archives date format', 'narihealth' ) ) );	
			// Yearly archive
			} elseif ( is_year() ) {
				$page_title = sprintf( get_the_date( _x( 'Y', 'yearly archives date format', 'narihealth' ) ) );	
			//Author
			} elseif ( is_author() ) { 
         		$page_title = sprintf( get_the_author() );
			// Standard title
			} else {
				$page_title = single_term_title("", false);
				if ( $page_title == '' ) {
					$post_id = get_the_ID();
					$page_title = get_the_title( $post_id );
				}
			}
		// Search
		} elseif( is_search() ) {
			/* translators: %s: search query. */
			$page_title =  sprintf( esc_html__( ' Search Results : %s', 'narihealth' ), get_search_query() );   
		// else
		} else {
			$post_id = get_the_ID();
			$page_title = get_the_title( $post_id );
		}
		return $page_title;
	} 
} 
// Page Header output
if ( ! function_exists( 'narihealth_page_header' ) ) {
	function narihealth_page_header() {
		global $post;
		$page_title	= narihealth_page_title();
		
		if ( is_front_page() || is_page() || is_single() ) return;
		if ( 'hide' == get_theme_mod( 'narihealth_archive_title_enable', 'show' )  ) return;
		$title_align = get_theme_mod( 'narihealth_page_title_section_align', 'text-left' );
?>
<div class="dtr-page-title-main <?php echo esc_attr( $title_align ); ?>">
    <div class="dtr-page-title-overlay"></div>
    <div class="container">
        <div class="dtr-page-title-wrapper">
            <?php if ( function_exists('bcn_display_list') && 'show' == get_theme_mod( 'narihealth_archive_breadcrumb_enable', 'show' ) ) { ?>
            <div class="dtr-breadcrumb-wrapper">
                <?php get_template_part( '/template-parts/header/breadcrumb' ); ?>
            </div>
            <?php } ?>
            <div class="dtr-page-title-content">
                <?php if ( 'show' == get_theme_mod( 'narihealth_archive_heading_enable', 'show' ) ) { ?>
                <h1 class="dtr-blog-title dtr-page-title" <?php narihealth_schema_markup( 'headline' ); ?>> <?php echo esc_html( $page_title ); ?> </h1>
                <?php } ?>
                <?php if ( is_home() && 'show' == get_theme_mod( 'narihealth_enable_page_desc', 'show' ) ) { ?>
                <?php $blog_desc = get_theme_mod( 'narihealth_blog_desc', esc_html__('Promoting Good Health Together','narihealth') ); ?>
                <p class="dtr-page-desc"><?php echo esc_html( $blog_desc ); ?></p>
                <?php } ?>
            </div>
        </div>
    </div>
</div>
<?php	
    } 
}