<?php
/**
 * Include and setup custom metaboxes and fields.
 */
add_action( 'cmb2_admin_init', 'narihealth_metaboxes' );
/**
 * Hook in and add a metabox
 */
function narihealth_metaboxes() {
	
	// Prefix
	$prefix = '_narihealth_';
	
	/**
	 * Testimonial Settings
	 */
	$narihealth_testimonial_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'testimonial-settings-metabox',
		'title'         => esc_html__( 'Testimonial Settings', 'narihealth' ),
		'object_types'  => array( 'dtr_testimonial' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
	) );
	
	$narihealth_testimonial_metabox->add_field( array(
		'desc'  =>  wp_kses( __( 'Title is used as ID to recognize respective testimonial. It will not be displayed frontend anywhere.<br>ID for Testimonial is <strong> Slug </strong> of Post === Title as viewed in permalink.', 'narihealth'), array( 'br' => array(), 'strong' => array(), 'i' => array(), ) ),
		'id'   	=> $prefix . 'testimonial_shorthand',
		'type' 	=> 'title',
	) );
	
     $narihealth_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Client Name', 'narihealth' ),
		'id'   	=> $prefix . 'testimonial_client_name',
		'type'	=> 'text',
	) );
	
    $narihealth_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Number of Stars', 'narihealth' ),
		'desc'  => esc_html__('Provide numerical here, any from - 5, 4, 3, 2, 1, 4-half, 3-half', 'narihealth'),
		'id'   	=> $prefix . 'testimonial_star_count',
		'type'	=> 'text',
		'default' => '5',
	) );
    
	$narihealth_testimonial_metabox->add_field( array(
		'name' => esc_html__( 'Review Platform Image', 'narihealth' ),
		'id'   =>  $prefix . 'testimonial_review_image',
		'type' => 'file',
	) );

    $narihealth_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Review Title', 'narihealth' ),
		'id'   	=> $prefix . 'testimonial_review_title',
		'type'	=> 'text',
	) );
    
    $narihealth_testimonial_metabox->add_field( array(
		'name'	=> esc_html__( 'Review Time', 'narihealth' ),
		'id'   	=> $prefix . 'testimonial_review_time',
		'type'	=> 'text',
	) );

	// Page Layout
	$page_layout = array(
		'' 					=> esc_html__( 'Default', 'narihealth' ),
		'dtr-fullwidth'		=> esc_html__( 'No Sidebar', 'narihealth' ),
		'dtr-right-sidebar'	=> esc_html__( 'Right Sidebar', 'narihealth' ),
		'dtr-left-sidebar' 	=> esc_html__( 'Left Sidebar', 'narihealth' ),
	);
	
	// Page Header Background image styles
	$page_header_bg_image_style = array(
		'repeat'	=> esc_html__( 'Repeat', 'narihealth' ),
		'stretched'	=> esc_html__( 'Stretched', 'narihealth' ),
		'fixed'		=> esc_html__( 'Fixed', 'narihealth' ),
	);

	/**
	 * Page Settings
	 */   
	$narihealth_page_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'page-settings-metabox',
		'title'         => esc_html__( 'Page Settings', 'narihealth' ),
		'object_types'  => array( 'page', 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
	) );

	$narihealth_page_metabox->add_field( array(
		'id'   		=> $prefix . 'page_layout_meta',
		'name' 		=> esc_html__( 'Sidebar Position', 'narihealth' ),
		'type' 		=> 'select',
		'options'	=> $page_layout,
	) );
    
    /**
	 * Page Info
	 */   
	$narihealth_page_info_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'page-info-metabox',
		'title'         => esc_html__( 'Page Info', 'narihealth' ),
		'object_types'  => array( 'page' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
	) );

	$narihealth_page_info_metabox->add_field( array(
		'id'   		=> $prefix . 'page_desc_meta',
		'name' 		=> esc_html__( 'Page Description', 'narihealth' ),
        'desc' 		=> esc_html__( 'Will be added below page title.', 'narihealth' ),
		'type'	=> 'text',
	) );
	
	/**
	 * Page Header
	 */
	$narihealth_page_header_metabox = new_cmb2_box( array(
		'id'            => $prefix . 'page-header-metabox',
		'title'         => esc_html__( 'Page Title Section Style', 'narihealth' ),
		'object_types'	=> array( 'page', 'post', 'dtr_testimonial' ), // Post type
		'context'    	=> 'normal',
		'priority'   	=> 'high',
	) );
	
	$narihealth_page_header_metabox->add_field( array(
		'name' => esc_html__( 'Page Title Background Image - Upload or enter URL', 'narihealth' ),
		'id'   =>  $prefix . 'page_header_bg_image',
		'type' => 'file',
	) );

	$narihealth_page_header_metabox->add_field( array(
		'id'   		=> $prefix . 'page_header_bg_image_style',
		'name' 		=> esc_html__( 'Page Title Background Style', 'narihealth' ),
		'type' 		=> 'select',
		'options'	=> $page_header_bg_image_style,
	) );

} // narihealth_metaboxes