<?php
/**
 * Contact Widget
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'NARIHEALTH_Contact_Widget' ) ) {
	class NARIHEALTH_Contact_Widget extends WP_Widget {
	
		/**
		 * Register widget
		 */
		public function __construct() {
			$widget_ops = array(
      			'classname' => 'narihealth_contact_widget',
      			'description' => esc_html__( 'Display Contact Button', 'narihealth' ),
    		);
    		parent::__construct( 'narihealth_contact_widget', esc_html__( 'Custom: Contact', 'narihealth' ), $widget_ops );
		}

		/**
	 	 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			// vars
			$output 		= '';
			$maintxt   		= empty( $instance['maintxt'] ) ? '' : $instance['maintxt'];
			$subtxt  		= empty( $instance['subtxt'] ) ? '' : $instance['subtxt'];
			$linkurl   		= empty( $instance['linkurl'] ) ? '' : $instance['linkurl'];
			$btntype  		= isset( $instance['btntype'] ) ? $instance['btntype'] : 'dtr-contact--email';
            $btnwidth  		= isset( $instance['btnwidth'] ) ? $instance['btnwidth'] : 'dtr-contact--full';

			// Before widget
			$output .= $args['before_widget'];

			// output starts
			$output .= '<div class="dtr-contact ' . esc_attr( $btntype ) .' ' . esc_attr( $btnwidth ) .' clearfix">';
                $output .= '<a class="dtr-contact__link" href="' . esc_html( $linkurl ) . '"></a>'; 
                    $output .= '<span class="dtr-contact__icon"></span>';
                    $output .= '<div class="dtr-contact__text">';
                        if ( $subtxt != '' ) {
                            $output .= '<p class="dtr-contact__sub-text">';
                                $output .= '' . esc_html( $subtxt ) . ''; 
                            $output .= '</p>';
                        }
                        if ( $maintxt != '' ) {
                            $output .= '<p class="dtr-contact__main-text">';
                                $output .= '' . esc_html( $maintxt ) . ''; 
                            $output .= '</p>';
                        }
                     $output .= '</div>';
			$output .= '</div>';
	
			// output ends

			// After widget
			$output .= $args['after_widget'];

			// output echo
			echo $output;
		
		} 

		/**
		 *  Update the information in the WordPress database
		 */	
		 
		public function update( $new_instance, $old_instance ) {
			$instance                 	= $old_instance;
			$instance['maintxt']  		= isset( $new_instance['maintxt'] ) ? trim( strip_tags( $new_instance['maintxt'] ) ) : '';
			$instance['subtxt']  		= isset( $new_instance['subtxt'] ) ? trim( strip_tags( $new_instance['subtxt'] ) ) : '';
			$instance['linkurl']  		= isset( $new_instance['linkurl'] ) ? trim( strip_tags( $new_instance['linkurl'] ) ) : '';
			$instance['btntype']        = ! empty( $new_instance['btntype'] ) ? strip_tags( $new_instance['btntype'] ) : 'dtr-contact--email';
            $instance['btnwidth']       = ! empty( $new_instance['btnwidth'] ) ? strip_tags( $new_instance['btnwidth'] ) : 'dtr-contact--full';
			
			/**
			 * Register strings for WPML translation
			 */
			if ( function_exists ( 'icl_register_string' ) ){
				icl_register_string('Contact Widget', 'Main Text', $instance['maintxt']);
				icl_register_string('Contact Widget', 'Sub Text', $instance['subtxt']);
			} // icl_register_string
				
			return $instance;
		} 

		/**
		 * btntype form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			
			extract( wp_parse_args( $instance, array(
				'maintxt'   => '',
				'subtxt'    => '',
				'linkurl'   => '',
				'btntype'   => 'dtr-contact--email',
                'btnwidth'  => 'dtr-contact--full',
			) ) ); ?>

<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'subtxt' ) ); ?>">
		<?php esc_html_e( 'Sub Text', 'narihealth' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'subtxt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'subtxt' ) ); ?>" type="text" value="<?php echo esc_attr( $subtxt ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'maintxt' ) ); ?>">
		<?php esc_html_e( 'Main Text - Number / Mail ID Text', 'narihealth' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'maintxt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'maintxt' ) ); ?>" type="text" value="<?php echo esc_attr( $maintxt ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'linkurl' ) ); ?>">
		<?php esc_html_e( 'Link / URL', 'narihealth' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'linkurl' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'linkurl' ) ); ?>" type="text" value="<?php echo esc_attr( $linkurl ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'btntype' ) ); ?>">
		<?php esc_html_e( 'Type', 'narihealth' ); ?>
	</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'btntype' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'btntype' ) ); ?>" class="widefat">
		<option value="dtr-contact--email" <?php selected( $btntype, 'dtr-contact--email' ) ?>>
		<?php esc_html_e( 'Email', 'narihealth' ); ?>
		</option>
		<option value="dtr-contact--phone" <?php selected( $btntype, 'dtr-contact--phone' ) ?>>
		<?php esc_html_e( 'Phone', 'narihealth' ); ?>
		</option>
	</select>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'btnwidth' ) ); ?>">
		<?php esc_html_e( 'Stretch', 'narihealth' ); ?>
	</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'btnwidth' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'btnwidth' ) ); ?>" class="widefat">
		<option value="dtr-contact--full" <?php selected( $btntype, 'dtr-contact--full' ) ?>>
		<?php esc_html_e( 'Full', 'narihealth' ); ?>
		</option>
		<option value="dtr-contact--default" <?php selected( $btntype, '' ) ?>>
		<?php esc_html_e( 'As Per Content', 'narihealth' ); ?>
		</option>
	</select>
</p>
<?php
		} 
	// class ends
	}
}
register_widget( 'NARIHEALTH_Contact_Widget' );