<?php
namespace NarihealthAddons;

use NarihealthAddons\Widgets\Narihealth_Section_Intro;
use NarihealthAddons\Widgets\Narihealth_Button;
use NarihealthAddons\Widgets\Narihealth_Link;
use NarihealthAddons\Widgets\Narihealth_Iconhead;
use NarihealthAddons\Widgets\Narihealth_Feature;
use NarihealthAddons\Widgets\Narihealth_Number_Feature;
use NarihealthAddons\Widgets\Narihealth_Icon_List;
use NarihealthAddons\Widgets\Narihealth_Rotating_Image;
use NarihealthAddons\Widgets\Narihealth_Animated_Heading;
use NarihealthAddons\Widgets\Narihealth_Blockquote;
use NarihealthAddons\Widgets\Narihealth_Icon;
use NarihealthAddons\Widgets\Narihealth_Testimonial_Carousel;
use NarihealthAddons\Widgets\Narihealth_Testimonial_Single;
use NarihealthAddons\Widgets\Narihealth_Recentposts_Carousel;
use NarihealthAddons\Widgets\Narihealth_Servicebox;
use NarihealthAddons\Widgets\Narihealth_Video_Lightbox;
use NarihealthAddons\Widgets\Narihealth_Marquee;
use NarihealthAddons\Widgets\Narihealth_Flipbox;
use NarihealthAddons\Widgets\Narihealth_Servicebox_Carousel;
use NarihealthAddons\Widgets\Narihealth_Team;
use NarihealthAddons\Widgets\Narihealth_Package;
use NarihealthAddons\Widgets\Narihealth_Accordion;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Main Plugin Class
 * Register new elementor widget.
 * @since 1.0.0
 */
class Narihealth_Elementor_Addons {
	
	/**
	 * Minimum Elementor Version
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '3.0.0';

	/**
	 * Constructor
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		$this->add_actions();
		$this->setup_hooks();
	}
	
	/**
	 * Add Actions
	 * @since 1.0.0
	 * @access private
	 */
	
	public function add_actions() {
		add_action( 'elementor/widgets/register', [ $this, 'on_widgets_registered' ] );
		add_action( 'elementor/init', array( $this, 'add_elementor_category' ) );
		
		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}
		
		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}
		
	}

	/**
	 * Admin notice
	 * Warning when the site doesn't have Elementor installed or activated.
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {
		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );
		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'narihealth' ),
			'<strong>' . esc_html__( 'Narihealth Elementor Addons', 'narihealth' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'narihealth' ) . '</strong>'
		);
		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
	
	/**
	 * Admin notice
	 * Warning when the site doesn't have a minimum required Elementor version.
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'narihealth' ),
			'<strong>' . esc_html__( 'Narihealth Elementor Addons', 'narihealth' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'narihealth' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Add setup_hooks
	 * @since 1.0.0
	 * @access private
	 */
	private function setup_hooks() {
		// Register Widget Styles
		add_action( 'elementor/editor/after_enqueue_styles', [ $this, 'widget_styles' ] );
		add_action( 'elementor/frontend/after_register_scripts',[ $this, 'register_frontend_scripts' ], 10 );
	}
	
	/**
	 * On Widgets Registered
	 * @since 1.0.0
	 * @access public
	 */
	public function on_widgets_registered() {
		$this->includes();
		$this->register_widget();
	}
	
	/**
	 * Add Category
	 * @since 1.0.0
	 * @access public
	 */
	 public function add_elementor_category() {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			'dtr-element',
			array(
				'title' => __('Narihealth Addons', 'narihealth'),
				'icon' => 'fa fa-plug',
			),
			1);
      }

	/**
	 * Includes
	 * @since 1.0.0
	 * @access private
	 */
	private function includes() {
		require __DIR__ . '/widgets/dtr-section-intro.php';
        require __DIR__ . '/widgets/dtr-button.php';
        require __DIR__ . '/widgets/dtr-link.php';
		require __DIR__ . '/widgets/dtr-icon-heading.php';
		require __DIR__ . '/widgets/dtr-feature.php';
		require __DIR__ . '/widgets/dtr-number-feature.php';
		require __DIR__ . '/widgets/dtr-icon-list.php';
		require __DIR__ . '/inc/dtr-icons.php';
		require __DIR__ . '/widgets/dtr-rotating-image.php';
		require __DIR__ . '/widgets/dtr-animated-heading.php';
		require __DIR__ . '/widgets/dtr-blockquote.php';
		require __DIR__ . '/widgets/dtr-icon.php';
		require __DIR__ . '/widgets/dtr-testimonial-carousel.php';
        require __DIR__ . '/widgets/dtr-testimonial-single.php';
		require __DIR__ . '/widgets/dtr-recentposts-carousel.php';
		require __DIR__ . '/widgets/dtr-servicebox.php';
		require __DIR__ . '/widgets/dtr-video-button.php';
		require __DIR__ . '/widgets/dtr-marquee.php';
        require __DIR__ . '/widgets/dtr-flipbox.php';
        require __DIR__ . '/widgets/dtr-servicebox-carousel.php';
        require __DIR__ . '/widgets/dtr-team.php';
        require __DIR__ . '/widgets/dtr-package.php';
        require __DIR__ . '/widgets/dtr-accordion.php';
	}

	/**
	 * Register Widget
	 * @since 1.0.0
	 * @access private
	 */
	private function register_widget() {
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Section_Intro() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Button() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Link() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Iconhead() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Feature() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Number_Feature() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Icon_List() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Rotating_Image() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Animated_Heading() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Blockquote() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Icon() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Testimonial_Carousel() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Testimonial_Single() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Recentposts_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Servicebox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Video_Lightbox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Marquee() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Flipbox() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Servicebox_Carousel() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Team() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Package() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Narihealth_Accordion() );
	}
	
	/**
	 * enqueue styles
	 * @since 1.0.0
	 * @access public
	 */
	public function widget_styles() {
		
		wp_enqueue_style( 'dtr-custom-icons', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'fonts/iconfont.css' );
		
		// elementor pro css mod
		$elementor_pro_mod = '';
		$elementor_pro_mod = get_theme_mod( 'narihealth_elementor_pro_mod', 'yes' );
		if ( $elementor_pro_mod == 'yes' && ! class_exists( 'ElementorPro\Plugin' ) ) {
			wp_enqueue_style( 'dtr-elementor-pro-mod', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/css/elementor-pro-mod.css' );
		}
	}
	
	/**
	 * Load Frontend Scripts
	 *
	 */
	public function register_frontend_scripts() {
		wp_register_script( 'swiper', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/swiper-bundle.min.js', array('jquery'), '5.0.3', true );
		wp_register_script( 'dtr-widgets', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', array('jquery'), '1.0', true );
		wp_enqueue_style( 'font-awesome-5-all', ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/all.min.css' );
    } 
	
}
new Narihealth_Elementor_Addons();