<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Blockquote extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-quote';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blockquote', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_blockquote_content',
			[
				'label' => esc_html__( 'Blockquote', 'narihealth' ),
			]
		);
		
		$this->add_control(
			'blockquote_style',
			[
				'label' => esc_html__( 'Quote Style', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-quote__center-align',
				'label_block' => true,
				'options' => [
					'dtr-quote__center-align'	=> esc_html__( 'Center Aligned', 'narihealth' ),
					'dtr-quote__left-align'	=> esc_html__( 'Left Aligned', 'narihealth' ),
					'dtr-quote__right-align'	=> esc_html__( 'Right Aligned', 'narihealth' ),
				],
			]
		);
		
		// Blockquote Text
		$this->add_control(
			'blockquote_content',
			[
				'label' => esc_html__( 'Blockquote Text', 'narihealth' ),
				'description' => esc_html__('Use &lt;br&gt; tag for line break', 'narihealth'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Blockquote Text.', 'narihealth' ),
				'placeholder' => esc_html__( 'Your Description', 'narihealth' ),
				'title' => esc_html__( 'Blockquote Text Here', 'narihealth' ),
				'separator' => 'none',
				'rows' => 10,
				'show_label' => true,
			]
		);
		
		$this->add_control(
			'blockquote_author',
			[
				'label' => esc_html__( 'Author Name', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'John Doe', 'narihealth' ),
				'placeholder' => esc_html__( 'Author Name Here', 'narihealth' ),
				'label_block' => true,
				'show_label' => true,
			]
		);
				
		$this->add_control(
			'blockquote_source',
			[
				'label' => esc_html__( 'Source', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Source', 'narihealth' ),
				'placeholder' => esc_html__( 'Source Here', 'narihealth' ),
				'label_block' => true,
				'show_label' => true,
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' => esc_html__( 'View', 'narihealth' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_blockquote_style',
			[
				'label' => esc_html__( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-quote__icon' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'content_style_control',
			[
				'label' 	=> esc_html__( 'Blockquote Text', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'blockquote_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} blockquote' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'blockquote_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} blockquote',
            ]
        );
		
		$this->add_control(
			'author_style_control',
			[
				'label' 	=> esc_html__( 'Author', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'blockquote_author_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-quote__author' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'blockquote_author_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-quote__author',
            ]
        );

		$this->add_control(
			'source_style_control',
			[
				'label' 	=> esc_html__( 'Source', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'blockquote_source_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-quote__source' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'blockquote_source_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-quote__source',
            ]
        );

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$html = ''; 
		$html .= '<div class="dtr-quote ' . esc_attr( $settings['blockquote_style'] ) . ' clearfix">';
		
		$html .= '<span class="dtr-quote__icon"></span>';
		if ( ! empty( $settings['blockquote_content'] ) ) {
			$html .= sprintf( '<blockquote>%s</blockquote>', wp_kses_post( $settings['blockquote_content'] ) );
		}
		if ( ! empty( $settings['blockquote_author'] ) ) {
			$html .= sprintf( '<p class="dtr-quote__author">%s</p>', esc_html( $settings['blockquote_author'] ) ); 
		}  
		if ( ! empty( $settings['blockquote_source'] ) ) {
			$html .= sprintf( '<span class="dtr-quote__source">%s</span>', esc_html( $settings['blockquote_source'] ) ); 
		}  
		$html .= '</div>';
		echo $html;	
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
		<#
		var html = '<div class="dtr-quote ' + settings.blockquote_style + ' clearfix">';
        html += '<span class="dtr-quote__icon"></span>';
		if ( settings.blockquote_content ) {
			html += '<blockquote>' + settings.blockquote_content + '</blockquote>';
		}
        if ( settings.blockquote_author ) {
			html += '<span class="dtr-quote__author">' + settings.blockquote_author + '</span>';
		}
		if ( settings.blockquote_source ) {
			html += '<span class="dtr-quote__source">' + settings.blockquote_source + '</span>';
		}
		html += '</div>';
		print( html );
		#>
		<?php
	}
}