<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Button extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-button';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Default Button', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => __( 'Theme Style Button', 'narihealth' ),
			]
		);
		
		$this->add_control(
			'btn_style',
			[
				'label' 	=> esc_html__( 'Style', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'dtr-btn dtr-btn--default',
				'options'	=> [
					'dtr-btn dtr-btn--default'	=> esc_html__( 'Default', 'narihealth' ),
					'dtr-btn--only-icon'		=> esc_html__( 'Only Icon - No text', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'btn_size',
			[
				'label' 	=> esc_html__( 'Size', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '',
				'options'	=> [
					''					=> esc_html__( 'Default', 'narihealth' ),
					'dtr-btn--small'	=> esc_html__( 'Small', 'narihealth' ),
				],
                'condition' => [
					'btn_style'	=> [ 'dtr-btn dtr-btn--default' ],
				],
			]
		);
		
		$this->add_control(
			'btn_radius',
			[
				'label' 	=> esc_html__( 'Border Radius', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'dtr-btn--rounded',
				'options'	=> [
					'dtr-btn--rounded'	=> esc_html__( 'Rounded Corners', 'narihealth' ),
					'dtr-btn--round'	=> esc_html__( 'Round', 'narihealth' ),
					'dtr-btn--square'	=> esc_html__( 'Square', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'link_text',
			[
				'label' => __( 'Text', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Click me', 'narihealth' ),
				'separator' => 'before',
				'placeholder' => __( 'Click me', 'narihealth' ),
				'condition' => [
					'btn_style'	=> [ 'dtr-btn dtr-btn--default' ],
				],
			]
		);
		
		$this->add_control(
			'icon_position',
			[
				'label' 	=> esc_html__( 'Icon Position', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '',
				'separator' => 'before',
				'options'	=> [
					''								=> esc_html__( 'No Icon', 'narihealth' ),
					'dtr-btn--icon-position-left'	=> esc_html__( 'Left', 'narihealth' ),
					'dtr-btn--icon-position-right'	=> esc_html__( 'Right', 'narihealth' ),
					'dtr-btn--icon-position-center'	=> esc_html__( 'For Only Icon Button', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'icon_library',
			[
				'label' => esc_html__( 'Icon Library', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-theme-custom-icons',
				'label_block' => true,
				'options' => [
					'dtr-font-awesome-icons'	=> esc_html__( 'Font Awesome Library', 'narihealth' ),
					'dtr-theme-custom-icons' 	=> esc_html__( 'Theme Custom Library', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'narihealth' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition' => [
					'icon_library' => [ 'dtr-font-awesome-icons' ],
				],
			]
		);

		// custom icons
		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'narihealth' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-arrow-right-long-solid',
				'label_block' => true,
				'condition' => [
					'icon_library'	=> [ 'dtr-theme-custom-icons' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'narihealth' ),
				'options' => dtr_icons(),
			]
		);
	
		$this->add_control(
			'link',
			[
				'label' => __( 'Link', 'narihealth' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'separator' => 'before',
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'narihealth' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left'    => [
						'title' => __( 'Left', 'narihealth' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'narihealth' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'narihealth' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'default' => 'left',
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'narihealth' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'narihealth' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Text Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn__text' => 'color: {{VALUE}};',
				],
			]
		);
				
		$this->add_control(
			'button_icon_color',
			[
				'label' => __( 'Icon Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn__icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label' => __( 'Background Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'button_border_color',
			[
				'label' => __( 'Border Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'button_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-btn__text',
				'condition' => [
					'btn_style'	=> [ 'dtr-btn dtr-btn--default' ],
				],
            ]
        );
		
		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'btn_style'	=> [ 'dtr-btn dtr-btn--default' ],
				],
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'default' => [
				'size' => '17',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-btn__icon' => 'font-size: {{SIZE}}{{UNIT}}',
				],
			]
		);
		
		// hover
		$this->add_control(
			'hover_style_control',
			[
				'label' => __( 'Hover', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'button_hover_text_color',
			[
				'label' => __( 'Text Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover .dtr-btn__text' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'button_hover_icon_color',
			[
				'label' => __( 'Icon Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover .dtr-btn__icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_background_color',
			[
				'label' => __( 'Background Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'Border Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
	}

		/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 

		// icon
		if ( ! empty( $settings['custom_icon'] ) ) {
			$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
			$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
		}
		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
		}
		$this->add_render_attribute( 'button', 'role', 'button' );
		
		// link text
		$this->add_render_attribute( [
			'link_text' => [
				'class' => 'dtr-btn__text',
			],
		] );
		$this->add_inline_editing_attributes( 'link_text', 'none' );
		?>
       	<a class="dtr-btn <?php echo $settings['btn_style']; ?> <?php echo $settings['btn_size']; ?> <?php echo $settings['icon_position']; ?> <?php echo $settings['btn_radius']; ?>" <?php echo $this->get_render_attribute_string( 'button' ); ?>>
        <?php if (  $settings['btn_style'] == 'dtr-btn dtr-btn--default' ) { ?>
		<?php if (  $settings['link_text'] != '' ) { ?>
            <span <?php echo $this->get_render_attribute_string( 'link_text' ); ?>><?php echo $settings['link_text']; ?></span>
        <?php } ?>
        <?php } ?>
        <?php if (  $settings['icon_position'] != '' ) { ?>
			<?php if ( $settings['icon_library'] == 'dtr-theme-custom-icons' && ! empty( $settings['default_icon'] ) ) { ?>
                <span class="dtr-icon dtr-btn__icon"><i <?php echo $this->get_render_attribute_string( 'custom_icon' ); ?>></i></span>
            <?php } else { ?>
                <span class="dtr-icon dtr-btn__icon"><?php Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
            <?php } ?>
        <?php } ?>
        </a>
	<?php }

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
	?> 
    <# iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
    <a class="dtr-btn {{ settings.icon_position }} {{ settings.btn_style }} {{ settings.btn_size }} {{ settings.btn_radius }}" href="{{ settings.link.url }}" role="button">
    <# if ( settings.btn_style == 'dtr-btn dtr-btn--default' ) { #>
        <# if ( settings.link_text != '' ) { #>
        	<span class="dtr-btn__text">{{{ settings.link_text }}}</span>
        <# } #> 
    <# } #> 
    <# if ( settings.icon_position != '' ) { #>
        <# if ( settings.icon_library == 'dtr-theme-custom-icons' ) { #>
            <span class="dtr-icon dtr-btn__icon"><i class="{{ settings.custom_icon }}"></i></span>
        <# } else {  #>
            <span class="dtr-icon dtr-btn__icon">{{{ iconHTML.value }}}</span>
        <#	} #>
    <#	} #>
    </a> 
	<?php
	}
}