<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Flipbox Widget
 */
class Narihealth_Flipbox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-flipbox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Flipbox', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_flipbox_content',
			[
				'label'	=> esc_html__( 'Flip Box', 'narihealth' ),
			]
		);
		
		// flip_effect
		$this->add_control(
			'flipbox_flip_effect',
			[
				'label' 	=> esc_html__( 'Flip Effect', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'dtr-flipbox-horiz dtr-flipbox-horiz-3d',
				'separator'	=> 'before',
				'options' 	=> [
					'dtr-flipbox-horiz'							=> esc_html__( 'Horizontal - Style 1', 'narihealth' ),
					'dtr-flipbox-horiz dtr-flipbox-horiz-3d'	=> esc_html__( 'Horizontal - Style 2', 'narihealth' ),
					'dtr-flipbox-vert'							=> esc_html__( 'Vertical - Style 1', 'narihealth' ),
					'dtr-flipbox-vert dtr-flipbox-vert-3d'		=> esc_html__( 'Vertical - Style 2', 'narihealth' ),
				],
			]
		);
        
        $this->add_control(
			'border_radius',
			[
				'label' 	=> esc_html__( 'Border Radius', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '',
				'options'	=> [
					''	                    => esc_html__( 'Rounded', 'narihealth' ),
					'dtr-square-corners'    => esc_html__( 'Square', 'narihealth' ),
				],
			]
		);

        $this->add_control(
			'flipbox_front_settings',
			[
				'label' 	=> esc_html__( 'Flip Front', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);	
        		
		$this->add_control(
			'icon_flipbox_icon_control',
			[
				'label' 	=> esc_html__( 'Image / Icon Settings', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'icon_flipbox_type',
			[
				'label' 	=> esc_html__( 'Type', 'narihealth' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'dtr-icon-flipbox-type-icon',
				'options' 	=> [
					'dtr-icon-flipbox-type-img'		=> esc_html__( 'Image', 'narihealth' ),
					'dtr-icon-flipbox-type-icon'	=> esc_html__( 'Icon', 'narihealth' ),
				],
			]
		);
		
		// image
		$this->add_control(
			'icon_flipbox_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
				'condition' => [
					'icon_flipbox_type'	=> [ 'dtr-icon-flipbox-type-img' ],
				],
			]
		);		
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'narihealth' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
				'condition'	=> [
					'icon_flipbox_type'	=> [ 'dtr-icon-flipbox-type-img' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
				'condition' => [
					'icon_flipbox_type'	=> [ 'dtr-icon-flipbox-type-img' ],
				],
			]
		);
		
		// icon
		$this->add_control(
			'icon_flipbox_icon_library',
			[
				'label' 		=> esc_html__( 'Icon Library', 'narihealth' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'dtr-font-awesome-icons',
				'separator' 	=> 'before',
				'label_block'	=> true,
				'options'	=> [
					'dtr-font-awesome-icons'	=> esc_html__( 'Font Awesome Library', 'narihealth' ),
					'dtr-theme-custom-icons'	=> esc_html__( 'Theme Custom Library', 'narihealth' ),
				],
				'condition' => [
					'icon_flipbox_type'	=> [ 'dtr-icon-flipbox-type-icon' ],
				],
			]
		);
		
		$this->add_control(
			'icon_flipbox_default_icon',
			[
				'label' 			=> esc_html__( 'Font Awesome Library', 'narihealth' ),
				'type' 				=> Controls_Manager::ICONS,
				'fa4compatibility'	=> 'icon',
				'default'			=> [
					'value' 	=> 'fas fa-star',
					'library'	=> 'fa-solid',
				],
				'label_block'		=> true,
				'condition'	=> [
					'icon_flipbox_icon_library'	=> [ 'dtr-font-awesome-icons' ],
					'icon_flipbox_type'			=> [ 'dtr-icon-flipbox-type-icon' ],
				],
			]
		);
		// custom icons
		$this->add_control(
			'icon_flipbox_custom_icon',
			[
				'label'			=> esc_html__( 'Theme Custom Library', 'narihealth' ),
				'type' 			=> Controls_Manager::SELECT2,
				'default' 		=> 'icon-quote-circle',
				'label_block'	=> true,
				'condition' 	=> [
					'icon_flipbox_icon_library'	=> [ 'dtr-theme-custom-icons' ],
					'icon_flipbox_type'			=> [ 'dtr-icon-flipbox-type-icon' ],
				],
				'description'	=> esc_html__( 'Icon demo file for extra icons is included in help document.', 'narihealth' ),
				'options' 		=> dtr_icons(),
			]
		);
		
		// heading
		$this->add_control(
			'flipbox_heading',
			[
				'label' 		=> esc_html__( 'Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Inspire', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Your Heading', 'narihealth' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
        
        $this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h3',
			]
		);
		
		// subheading
		$this->add_control(
			'flipbox_subheading',
			[
				'label' 		=> esc_html__( 'Sub Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'The Best Inspiration Ever', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Your Sub Heading', 'narihealth' ),
				'label_block' 	=> true,
				'separator'	 	=> 'before',
			]
		);
	    
		$this->add_control(
			'flipbox_back_settings',
			[
				'label' 	=> esc_html__( 'Flip Back', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);	
        
        // content
		$this->add_control(
			'flipbox_back_content',
			[
				'label' 		=> esc_html__( 'Content', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Lorem ipsum dolor sit amet consectetur adipiscing labore et dolore magna aliqua. ', 'narihealth' ),
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'narihealth' ),
				'label_block' 	=> true,
			]
		);
		
		// link
		$this->add_control(
			'flipbox_link_control',
			[
				'label' 	=> esc_html__( 'Link', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_control(
			'link_text',
			[
				'label' 		=> esc_html__( 'Link Text', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Learn More', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Learn More', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		); 

		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'narihealth' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default'	=> [
					'url'	=> '#',
				],
			]
		);
        
		$this->add_control(
			'flipbox_padding_settings',
			[
				'label' 	=> esc_html__( 'Padding - Front Side', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
        
        $this->add_responsive_control(
			'front_padding_y',
			[
				'label' => esc_html__( 'Top / Bottom', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-flipbox__front ' => 'padding-top: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);
        
       $this->add_responsive_control(
			'front_padding_x',
			[
				'label' => esc_html__( 'Left / Right', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-flipbox__front ' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}}',
				],
			]
		);
        
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'narihealth' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_flipbox_style',
			[
				'label' => esc_html__( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
        // background image
		$this->add_control(
			'flipbox_bg_image_control',
			[
				'label' 	=> esc_html__( 'Flip Front', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_control(
			'front_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-flipbox__front'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'flipbox_bg_image',
			[
				'label' 		=> __( 'Background Image', 'narihealth' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default'		=> [
					'url'	=> '',
				],
				'selectors'		=> [
				'{{WRAPPER}} .dtr-flipbox__front'	=> 'background-image: url("{{URL}}");',
			],
			
			]
		);
		
		$this->add_control(
			'flipbox_bg_image_position',
			[
				'label' 	=> __( 'Background Position', 'narihealth' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options'	=> [
					'' 			=> _x( 'Default', 'Background Control', 'narihealth' ),
				'top left' 		=> _x( 'Top Left', 'Background Control', 'narihealth' ),
				'top center' 	=> _x( 'Top Center', 'Background Control', 'narihealth' ),
				'top right' 	=> _x( 'Top Right', 'Background Control', 'narihealth' ),
				'center left' 	=> _x( 'Center Left', 'Background Control', 'narihealth' ),
				'center center'	=> _x( 'Center Center', 'Background Control', 'narihealth' ),
				'center right' 	=> _x( 'Center Right', 'Background Control', 'narihealth' ),
				'bottom left' 	=> _x( 'Bottom Left', 'Background Control', 'narihealth' ),
				'bottom center' => _x( 'Bottom Center', 'Background Control', 'narihealth' ),
				'bottom right' 	=> _x( 'Bottom Right', 'Background Control', 'narihealth' ),
				],
				'selectors'	=> [
				'{{WRAPPER}} .dtr-flipbox__front'	=> 'background-position: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'flipbox_bg_image_repeat',
			[
				'label'		=> __( 'Background Repeat', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options'	=> [
					'' 		=> _x( 'Default', 'Background Control', 'narihealth' ),
				'no-repeat'	=> _x( 'No-repeat', 'Background Control', 'narihealth' ),
				'repeat' 	=> _x( 'Repeat', 'Background Control', 'narihealth' ),
				'repeat-x'	=> _x( 'Repeat-x', 'Background Control', 'narihealth' ),
				'repeat-y' 	=> _x( 'Repeat-y', 'Background Control', 'narihealth' ),
				],
				'selectors' => [
				'{{WRAPPER}} .dtr-flipbox__front'	=> 'background-repeat: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'flipbox_bg_image_size',
			[
				'label' 	=> __( 'Background Image Size', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options'	=> [
					''		=> _x( 'Default', 'Background Control', 'narihealth' ),
				'auto' 		=> _x( 'Auto', 'Background Control', 'narihealth' ),
				'cover' 	=> _x( 'Cover', 'Background Control', 'narihealth' ),
				'contain'	=> _x( 'Contain', 'Background Control', 'narihealth' ),
				],
				'selectors' => [
				'{{WRAPPER}} .dtr-flipbox__front' => 'background-size: {{VALUE}};',
				],
			]
		);
        
        // icon
		$this->add_control(
			'flipbox_iconstyle_control',
			[
				'label' 	=> esc_html__( 'Icon', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
        
		$this->add_control(
			'icon_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-flipbox__img, {{WRAPPER}} .dtr-flipbox__img i'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		// heading
		$this->add_control(
			'flipbox_heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Heading', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-flipbox__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'flipbox_heading_typo',
				'label' 	=> esc_html__( 'Flipbox Heading Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-flipbox__heading',
            ]
        );
		
		// subheading
		$this->add_control(
			'flipbox_subheading_style_control',
			[
				'label' 	=> esc_html__( 'Sub Heading', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'subheading_color',
			[
				'label' 	=> esc_html__( 'Sub Heading', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-flipbox__subheading'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'flipbox_subheading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-flipbox__subheading',
            ]
        );
	
		// back
		$this->add_control(
			'flipbox_back_style_control',
			[
				'label' 	=> esc_html__( 'Flip Back', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'back_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-flipbox__back'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		// content
		$this->add_control(
			'flipbox_content_style_control',
			[
				'label' 	=> esc_html__( 'Content', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Content', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-flipbox__back-content'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'flipbox_content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-flipbox__back-content',
            ]
        );
		
		// link
		$this->add_control(
			'flipbox_link_style_control',
			[
				'label' 	=> esc_html__( 'Link', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'link_text_color',
			[
				'label' 	=> esc_html__( 'Text Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text'	=> 'color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_color',
			[
				'label' 	=> esc_html__( 'Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_hover_color',
			[
				'label' 	=> esc_html__( 'On Hover: Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}}.dtr-link__text::after'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'link_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-link__text',
            ]
        );
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		
        // link
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
		}
		$this->add_render_attribute( 'button', 'role', 'button' );
		
		// custom icon
		if ( ! empty( $settings['icon_flipbox_custom_icon'] ) ) {
			$this->add_render_attribute( 'icon_flipbox_custom_icon', 'class', 'dtr-icon' );
			$this->add_render_attribute( 'icon_flipbox_custom_icon', 'class', $settings['icon_flipbox_custom_icon'] );
			$this->add_render_attribute( 'icon_flipbox_custom_icon', 'aria-hidden', 'true' );
		} ?>

	<div class="dtr-flipbox <?php echo esc_attr( $settings['flipbox_flip_effect'] ) ?> <?php echo $settings['border_radius']; ?>">
		<div class="dtr-flipbox__front">
			<div class="dtr-flipbox__front-content">
				<div class="dtr-flipbox__img">
					<?php if ( $settings['icon_flipbox_type'] == 'dtr-icon-flipbox-type-icon' ) { 
						if ( $settings['icon_flipbox_icon_library'] == 'dtr-theme-custom-icons' && ! empty( $settings['icon_flipbox_default_icon'] ) ) { ?>
						<i <?php echo $this->get_render_attribute_string( 'icon_flipbox_custom_icon' ); ?>></i>
					<?php } else { ?>
						<?php Icons_Manager::render_icon( $settings['icon_flipbox_default_icon'], [ 'aria-hidden' => 'true' ] ); ?>
					<?php } ?>
					<?php } elseif ( $settings['icon_flipbox_type'] == 'dtr-icon-flipbox-type-img' && ! empty( $settings['image']['url'] ) ) {
							$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
							$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
							$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
							$image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); 
							echo $image_html;
					} else {} ?>
				</div>
				<?php if ( ! empty( $settings['flipbox_heading'] ) ) { ?>
				<<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-flipbox__heading"><?php echo wp_kses_post( $settings['flipbox_heading'] ) ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
				<?php } ?>
				<?php if ( ! empty( $settings['flipbox_subheading'] ) ) { ?>
				<p class="dtr-flipbox__subheading"><?php echo wp_kses_post( $settings['flipbox_subheading'] ) ?></p>
				<?php } ?>
			</div>
		</div>
		<div class="dtr-flipbox__back">
			<?php if ( ! empty( $settings['flipbox_back_content'] ) ) { ?>
			<div class="dtr-flipbox__back-content"><?php echo wp_kses_post( $settings['flipbox_back_content'] ) ?></div>
			<?php } ?>
			<?php if ( ! empty( $settings['link_text'] ) ) { ?>
            <div class="dtr-flipbox__link-wrap">
            <a class="dtr-link" <?php echo $this->get_render_attribute_string( 'button' ); ?>>
            <span class="dtr-link__text"><?php echo esc_html( $settings['link_text'] ); ?></span>
            </a>
            </div>
			<?php } ?>
		</div>
	</div>
	<?php
		}
	
		/**
		 * Render widget output in the editor.
		 * Written as a Backbone JavaScript template and used to generate the live preview.
		 * @access protected
		 */
		protected function content_template() {
		?>
		
		<div class="dtr-flipbox {{ settings.flipbox_flip_effect }} {{ settings.border_radius }}">
			<div class="dtr-flipbox__front">
				<div class="dtr-flipbox-front--content">
					<div class="dtr-flipbox__img">
						<# iconHTML = elementor.helpers.renderIcon( view, settings.icon_flipbox_default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
						<# if( settings.icon_flipbox_type == 'dtr-icon-flipbox-type-icon' ) {
							if ( settings.icon_flipbox_icon_library == 'dtr-theme-custom-icons' ) { #>
								<i class="{{ settings.icon_flipbox_custom_icon }}"></i> 	
						 <# } else {  #>
								{{{ iconHTML.value }}}	
						 <#	}
						 } else {
							var image = {
							id: settings.image.id,
							url: settings.image.url,
							size: settings.thumbnail_size,
							dimension: settings.thumbnail_custom_dimension,
							model: view.getEditModel()
							};
							var image_url = elementor.imagesManager.getImageUrl( image ); #>  
							<img src="{{ image_url }}"/>
						 <# } #>	
					</div>
					<# if ( settings.flipbox_heading != '' ) { #>
					<{{ settings.heading_size }} class="dtr-flipbox__heading">{{{ settings.flipbox_heading }}}</{{ settings.heading_size }}>
					<# } #>
					<# if ( settings.flipbox_subheading != '' ) { #>
						<p class="dtr-flipbox__subheading">{{{ settings.flipbox_subheading }}}</p>
					<# } #>
				</div>
			</div>
			<div class="dtr-flipbox__back">	
			<# if ( settings.flipbox_back_content != '' ) { #>
				<div class="dtr-flipbox__back-content">{{{ settings.flipbox_back_content }}}</div>
			<# } #>
			<# if ( settings.link.url != '' ) { #> 
            <div class="dtr-flipbox__link-wrap">
            <a class="dtr-link" href="{{ settings.link.url }}" role="button">
                <span class="dtr-link__text">{{{ settings.link_text }}}</span>
            </a>
            </div> 
            <# } #>
			</div>	
		</div>
<?php
	}
}