<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Link extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-link';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Link', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_link',
			[
				'label' => __( 'Link', 'narihealth' ),
			]
		);
		
         $this->add_control(
			'icon_enable',
			[
				'label' => esc_html__( 'Icon', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'  => esc_html__( 'Show', 'narihealth' ),
					'hide'  => esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
        
		$this->add_control(
			'link_icon_type',
			[
				'label' 	=> esc_html__( 'Icon Type', 'narihealth' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'icon-type-icon',
				'separator'	=> 'before',
				'options' 	=> [
					'icon-type-icon'		=> esc_html__( 'Font Awesome Icon', 'narihealth' ),
					'icon-type-img'			=> esc_html__( 'Image', 'narihealth' ),
					'icon-type-custom-icon'	=> esc_html__( 'Theme Icon', 'narihealth' ),
					'icon-type-html'		=> esc_html__( 'Custom HTML', 'narihealth' ),
				],
			]
		);

		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'narihealth' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition' => [
					'link_icon_type' => [ 'icon-type-icon' ],
				],
			]
		);

		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'narihealth' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-star-solid',
				'label_block' => true,
				'condition' => [
					'link_icon_type'	=> [ 'icon-type-custom-icon' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'narihealth' ),
				'options' => dtr_icons(),
			]
		);
		
		$this->add_control(
			'link_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'condition' => [
					'link_icon_type'	=> [ 'icon-type-img' ],
				],
			]
		);	
			
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'narihealth' ),
				'type' 		=> Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default'	=> [
					'url'	=> NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
				'condition'	=> [
					'link_icon_type'	=> [ 'icon-type-img' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
				'condition' => [
					'link_icon_type'	=> [ 'icon-type-img' ],
				],
			]
		);
		
		$this->add_control(
			'link_icon_html',
			[
				'label' => __( 'Custom HTML', 'narihealth' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'label_block' => true,
				'condition' => [
					'link_icon_type'	=> [ 'icon-type-html' ],
				],
			]
		);
		
		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'separator' => 'before',
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
					'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-link__icon' => 'font-size: {{SIZE}}{{UNIT}}',
				],
			]
		);
        
        $this->add_control(
			'icon_m_right',
			[
				'label' => esc_html__( 'Icon - Margin Right', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'default' => [
					'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-link__icon' => 'margin-right: {{SIZE}}{{UNIT}}',
				],
			]
		);
		
		$this->add_control(
			'link_text',
			[
				'label' 		=> esc_html__( 'Link Text', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Learn More', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Learn More', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		); 

		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'narihealth' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default'	=> [
					'url'	=> '#',
				],
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'narihealth' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'narihealth' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-link__icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'link_text_color',
			[
				'label' 	=> esc_html__( 'Text Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text'	=> 'color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_color',
			[
				'label' 	=> esc_html__( 'Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_hover_color',
			[
				'label' 	=> esc_html__( 'On Hover: Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::after'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'link_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-link__text',
            ]
        );

		$this->end_controls_section();
	}

		/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['link'] );
		}
		$this->add_render_attribute( 'button', 'role', 'button' );
		// icon
		if ( ! empty( $settings['custom_icon'] ) ) {
			$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
			$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
		}
		?>
        <?php if ( ! empty( $settings['link']['url'] ) ) { ?>
        <div class="dtr-link-wrap">
        <a class="dtr-link" <?php echo $this->get_render_attribute_string( 'button' ); ?>>
            <?php if ( $settings['icon_enable'] == 'show' ) { ?> 
            <span class="dtr-icon dtr-link__icon">
                <?php if ( $settings['link_icon_type'] == 'icon-type-icon' && ! empty( $settings['default_icon'] ) ) { 
                                    Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); 
                                } elseif ( $settings['link_icon_type'] == 'icon-type-custom-icon' && ! empty( $settings['custom_icon'] ) ) { ?>
                <i <?php echo $this->get_render_attribute_string( 'custom_icon' ); ?>></i>
                <?php } elseif ( $settings['link_icon_type'] == 'icon-type-img' && ! empty( $settings['image']['url'] ) ) { 
                                    $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                                    $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                                    $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                                    $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
                                    echo $image_html;
                                } elseif ( $settings['link_icon_type'] == 'icon-type-html' && ! empty( $settings['link_icon_html'] ) ) {
                                    echo wp_kses_post( $settings['link_icon_html'] );
                                } else {}  ?>
            </span> 
            <?php } ?>
            <span class="dtr-link__text">
                <?php echo esc_html( $settings['link_text'] ); ?>
            </span>
        </a>
        </div>
        <?php } ?>

<?php	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
     <# iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
     <# if ( settings.link.url != '' ) { #> 
     <div class="dtr-link-wrap">
     <a class="dtr-link" href="{{ settings.link.url }}" role="button">
        <# if ( settings.icon_enable == 'show' ) { #>
        <span class="dtr-icon dtr-link__icon"> 
            <# if ( settings.link_icon_type == 'icon-type-icon' ) { #>
            {{{ iconHTML.value }}}
            <# } else if ( settings.link_icon_type == 'icon-type-custom-icon' ) { #> <i class="{{ settings.custom_icon }}"></i> <# } else if ( settings.link_icon_type == 'icon-type-img' ) { #>
            <#
            var image = {
            id: settings.image.id,
            url: settings.image.url,
            size: settings.thumbnail_size,
            dimension: settings.thumbnail_custom_dimension,
            model: view.getEditModel()
            };
            var image_url = elementor.imagesManager.getImageUrl( image );  #> <img src="{{ image_url }}"/> <# } else if ( settings.link_icon_type == 'icon-type-html' ) { #>
            {{{ settings.link_icon_html }}}
            <# } else { } #> 
        </span>
        <# } #>
        <span class="dtr-link__text">{{{ settings.link_text }}}</span>
     </a> 
     </div>
     <# } #>
<?php
	}
}