<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Stroke;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Marquee extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-marquee';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Text Marquee', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_marquee_content',
			[
				'label'	=> esc_html__( 'Text Marquee', 'narihealth' ),
			]
		);

		// content
		$this->add_control(
			'marquee_content',
			[
				'label' 		=> esc_html__( 'Content', 'narihealth' ),
				'description'	=> esc_html__( 'Use this span to add icon between words ------ <span class="mrq-icon"></span>. ------- If you have short content, just repeat the content once or twice in the same textarea just next to your text. This will make text to occupy available page width, so no blank space will show up.', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Best Design. Modern Look. Great Time.', 'narihealth' ),
				'separator'		=> '',
				'placeholder' 	=> esc_html__( 'Your Content', 'narihealth' ),
				'label_block' 	=> true,
			]
		);
		
				
		$this->add_control(
			'scroll_direction',
			[
				'label' 	=> esc_html__( 'Scroll Direction', 'errandco' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'dtr-marquee-l',
				'separator' => 'before',
				'options'	=> [
					''				=> esc_html__( 'Right to Left', 'errandco' ),
					'dtr-marquee-l'	=> esc_html__( 'Left to Right', 'errandco' ),
				],
			]
		);
		
		$this->add_responsive_control(
			'scroll_speed',
			[
				'label' => esc_html__( 'Animation Speed', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'separator' => 'before',
				'range' => [
					'px' => [
						'max' => 300,
					],
				],
				'default' => [
				'size' => 15,
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-marquee' => 'animation-duration: calc({{SIZE}}s)',
				],
			]
		);
		
		$this->add_control(
			'icon_margin',
			[
				'label' => esc_html__( 'Left-Right Margin To Separator Icon', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'separator'		=> 'before',
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
				'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} span.mrq-icon' => 'margin: 0 {{SIZE}}{{UNIT}}',
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'narihealth' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_marquee_style',
			[
				'label' => esc_html__( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'text_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-marquee'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' 	=> esc_html__( 'Separator Icon Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} span.mrq-icon'	=> 'color: {{VALUE}};',
				],
			]
		);
	
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-marquee',
            ]
        );
		
		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'text_stroke',
				'selector' => '{{WRAPPER}} .dtr-marquee',
			]
		);

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		?>
        <div class="dtr-marquee-wrapper">  
            <div class="dtr-marquee <?php echo esc_attr( $settings['scroll_direction'] ) ?>">
                <?php if ( ! empty( $settings['marquee_content'] ) ) { ?>
                    <span><?php echo wp_kses_post( $settings['marquee_content'] ) ?></span>
                    <span><?php echo wp_kses_post( $settings['marquee_content'] ) ?></span>
                    <span><?php echo wp_kses_post( $settings['marquee_content'] ) ?></span>
                <?php } ?>
               
            </div>
        </div>
	<?php
    }
	
		/**
		 * Render widget output in the editor.
		 * Written as a Backbone JavaScript template and used to generate the live preview.
		 * @access protected
		 */
		protected function content_template() {
		?>
        <div class="dtr-marquee-wrapper">  
            <div class="dtr-marquee {{{settings.scroll_direction }}}">                
                <# if ( settings.marquee_content ) { #>
                    <span>{{{ settings.marquee_content }}}</span>
                    <span>{{{ settings.marquee_content }}}</span>
                    <span>{{{ settings.marquee_content }}}</span>
                <# } #>
            </div>
        </div>
<?php
	}
}