<?php
namespace NarihealthAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Package Widget
 */
class Narihealth_Package extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-package';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Package / Fees', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// main
		$this->start_controls_section(
			'section_main_content',
			[
				'label'	=> esc_html__( 'Package', 'narihealth' ),
			]
		);

		// heading
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
				
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h4',
			]
		);

		$this->add_control(
			'package_price',
			[
				'label' 		=> esc_html__( 'Price', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( '$264', 'narihealth' ),
				'placeholder' 	=> esc_html__( '$264', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);

		// content
		$this->add_control(
			'package_content',
			[
				'label' 		=> esc_html__( 'Content', 'narihealth' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'default' 		=> '',
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'narihealth' ),
				'default' 		=> esc_html__( 'Content Goes Here', 'narihealth' ),
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'narihealth' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'line_color',
			[
				'label' 	=> esc_html__( 'Line Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-package__heading::after'	=> 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'heading_bg_color',
			[
				'label' 	=> esc_html__( 'Heading Background Color', 'narihealth' ),
                'label' 	=> esc_html__( 'To match background color, on which element is placed', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-package__heading'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-package__heading'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-package__heading',
            ]
        );
		
		// price
		$this->add_control(
			'price_style',
			[
				'label' => esc_html__( 'Price', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'price_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-package__price'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'price_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-package__price',
            ]
        );
		
		// content
		$this->add_control(
			'content_style',
			[
				'label' => esc_html__( 'Content', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-package__content'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'content_link_color',
			[
				'label' 	=> esc_html__( 'Link in Content', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-package__content a'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'content_link_hover_color',
			[
				'label' 	=> esc_html__( 'Hover to - Link in Content', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-package__content a:hover'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-package__content',
            ]
        );
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
	  	?>
    <div class="dtr-package">
        <div class="dtr-package__head">
            <div class="dtr-package__heading-wrap">
                <?php if ( ! empty( $settings['heading'] ) ) { ?>
                    <<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-package__heading"><?php echo wp_kses_post( $settings['heading'] ); ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
                <?php } ?>
            </div>
             <?php if ( ! empty( $settings['package_price'] ) ) { ?>
                <div class="dtr-package__price"><?php echo esc_html( $settings['package_price'] ) ?></div>
            <?php } ?>
        </div>
        <?php if ( ! empty( $settings['package_content'] ) ) { ?>
        	<div class="dtr-package__content"><?php echo wp_kses_post( $settings['package_content'] ) ?></div>
        <?php } ?>
</div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
    <div class="dtr-package">
        <div class="dtr-package__head">
            <div class="dtr-package__heading-wrap">
                <# if ( settings.heading != '' ) { #>
                <{{ settings.heading_size }} class="dtr-package__heading"> {{{ settings.heading }}}</{{ settings.heading_size }}>
                <# } #>
            </div>
             <# if ( settings.package_price != '' ) { #>
            <div class="dtr-package__price">{{{ settings.package_price }}}</div>
            <# } #>
        </div>
        <# if ( settings.package_content != '' ) { #>
        <div class="dtr-package__content">{{{ settings.package_content }}}</div>
        <# } #>
</div>
<?php
	}
}