<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Pricing extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-pricing';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		// content control starts
		// image
		$this->start_controls_section(
			'section_main_content',
			[
				'label' => __( 'Pricing', 'narihealth' ),
			]
		);

		$this->add_control(
			'pricing_table_type',
			[
				'label' 	=> esc_html__( 'Table Type', 'narihealth' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> '',
				'options' 	=> [
					''						=> esc_html__( 'Default', 'narihealth' ),
					'dtr-pricing__popular'	=> esc_html__( 'Focused / Highlighted', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'pricing_icon_control',
			[
				'label' 	=> esc_html__( 'Image / Icon Settings', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'pricing_icon_img_type',
			[
				'label' 	=> esc_html__( 'Type', 'narihealth' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'dtr-icon-pricing-type-icon',
				'options' 	=> [
					'dtr-icon-pricing-type-img'		=> esc_html__( 'Image', 'narihealth' ),
					'dtr-icon-pricing-type-icon'	=> esc_html__( 'Icon', 'narihealth' ),
					'dtr-icon-pricing-type-html'	=> esc_html__( 'Custom HTML', 'narihealth' ),
				],
			]
		);

		// image
		$this->add_control(
			'pricing_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'condition' => [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-img' ],
				],
			]
		);	
			
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'narihealth' ),
				'type' 		=> Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default'	=> [
					'url'	=> NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
				'condition'	=> [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-img' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'image',
				'default' 	=> 'large',
				'separator'	=> 'none',
				'condition' => [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-img' ],
				],
			]
		);
		
		
		// custom icon
		$this->add_control(
			'pricing_icon_img_html',
			[
				'label' => __( 'Custom HTML', 'narihealth' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'label_block' => true,
				'condition' => [
					'pricing_icon_img_type'	=> [ 'dtr-icon-pricing-type-html' ],
				],
			]
		);
		
		// icon
		$this->add_control(
			'pricing_icon',
			[
				'label' => __( 'Icon', 'elementor' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'		=> true,
				'condition'	=> [
					'pricing_icon_img_type'			=> [ 'dtr-icon-pricing-type-icon' ],
				],
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
			]
		);
			
	    // pricing_tagline
		$this->add_control(
			'pricing_tagline',
			[
				'label' => __( 'Tagline', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Your Tagline', 'narihealth' ),
				'label_block' => true,
				'separator'	=> 'before',
			]
		);
		
		// pricing_title
		$this->add_control(
			'pricing_title',
			[
				'label' => __( 'Heading', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Premium Plan', 'narihealth' ),
				'separator'	=> 'before',
				'label_block' => true,
			]
		);

		// pricing_price
		$this->add_control(
			'pricing_currency',
			[
				'label' => __( 'Currency', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '$', 'narihealth' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'pricing_price',
			[
				'label' => __( 'Price', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '199', 'narihealth' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'pricing_desc',
			[
				'label' => __( 'Duration', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '/year', 'narihealth' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'pricing_description',
			[
				'label' 		=> esc_html__( 'Short Description', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> '',
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Plan intro goes here', 'narihealth' ),
				'label_block' 	=> true,
			]
		);
		
		$this->add_control(
			'pricing_content',
			[
				'label' 		=> esc_html__( 'Content', 'narihealth' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'default' 		=> '',
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content / List', 'narihealth' ),
				'label_block' 	=> true,
			]
		);
		
		// button
		$this->add_control(
			'link_text',
			[
				'label' => __( 'Button Text', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Buy Now', 'narihealth' ),
				'description' => __('Leave blank if need to hide button.', 'narihealth'),
				'placeholder' => __( 'Your Button Text', 'narihealth' ),
				'label_block' => true,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'narihealth' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default'	=> [
					'url'	=> '#',
				],
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'narihealth' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		$this->end_controls_section();
		// content control ends
		
		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		// box
		$this->add_control(
			'pricing_box_style_control',
			[
				'label' => __( 'Pricing box', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'pricing_box_bg',
			[
				'label' => __( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_box_border',
			[
				'label' => __( 'Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_compiled_color',
			[
				'label' => __( 'Pricing Base Text Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_icon_bg_color',
			[
				'label' => __( 'Icon Background Color', 'narihealth' ),
				'default' => '',
				'separator' => 'before',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__icon-wrapper' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'pricing_icon_color',
			[
				'label' => __( 'Icon Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__icon' => 'color: {{VALUE}};',
				],
			]
		);

		// tagline
		$this->add_control(
			'tagline_style_control',
			[
				'label' => __( 'Tagline', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'pricing_tagline_bg_color',
			[
				'label' => __( 'Background Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__tagline' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_tagline_color',
			[
				'label' => __( 'Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__tagline' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_tagline_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__tagline',
            ]
        );
		
		// title
		$this->add_control(
			'title_style_control',
			[
				'label' => __( 'Heading', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'pricing_title_color',
			[
				'label' => __( 'Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__heading' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_title_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__heading',
            ]
        );
		
		// description
		$this->add_control(
			'description_style_control',
			[
				'label' => __( 'Description', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__description' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_description_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__description',
            ]
        );
		
		// price
		$this->add_control(
			'price_style_control',
			[
				'label' => __( 'Price', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'pricing_price_color',
			[
				'label' => __( 'Value Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__price_value' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_price_typo',
				'label' 	=> esc_html__( 'Value Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__price_value',
            ]
        );
		
		$this->add_control(
			'pricing_currency_color',
			[
				'label' => __( 'Currency Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__currency' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_currency_typo',
				'label' 	=> esc_html__( 'Currency Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__currency',
            ]
        );
		
		
		$this->add_control(
			'pricing_price_desc_color',
			[
				'label' => __( 'Price Desc Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__price_desc' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_price_desc_typo',
				'label' 	=> esc_html__( 'Price Desc Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__price_desc',
            ]
        );
		
		// content
		$this->add_control(
			'content_style_control',
			[
				'label' => __( 'Content', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-pricing__content' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'pricing_content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-pricing__content',
            ]
        );
				
		$this->add_control(
			'content_list_icon_color',
			[
				'label' => __( 'List Icon Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}}  .dtr-pricing__content li::before' => 'color: {{VALUE}};',
				],
			]
		);
		
		// button
		$this->add_control(
			'button_style_control',
			[
				'label' => __( 'Button', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'pricing_button_bg',
			[
				'label' => __( 'Background Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'pricing_button_color',
			[
				'label' => __( 'Text Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'pricing_button_hover_bg',
			[
				'label' => __( 'Hover: Background Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'pricing_button_hover_color',
			[
				'label' => __( 'Hover: Text Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		
		// button
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_render_attribute( 'button', 'href', $settings['link']['url'] );
			$this->add_render_attribute( 'button', 'class', 'dtr-btn dtr-pricing__btn' );
			if ( $settings['link']['is_external'] ) {
				$this->add_render_attribute( 'button', 'target', '_blank' );
			}
			if ( $settings['link']['nofollow'] ) {
				$this->add_render_attribute( 'button', 'rel', 'nofollow' );
			}
		}
		$this->add_render_attribute( 'button', 'role', 'button' );
		?>
		<div class="dtr-pricing <?php echo esc_attr( $settings['pricing_table_type'] ) ?>">
        	<?php if ( ! empty( $settings['pricing_tagline'] ) ) { ?>
            	<p class="dtr-pricing__tagline"><?php echo esc_html( $settings['pricing_tagline'] ); ?></p>
            <?php } ?>
            <div class="dtr-pricing__icon-wrapper">
                <?php	if ( $settings['pricing_icon_img_type'] == 'dtr-icon-pricing-type-icon' ) { ?>
                    <span class="dtr-pricing__icon"><?php Icons_Manager::render_icon( $settings['pricing_icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
                <?php } elseif ( $settings['pricing_icon_img_type'] == 'dtr-icon-pricing-type-img' && ! empty( $settings['image']['url'] ) ) {
                        $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                        $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                        $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                        $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings ); ?>
                        <span class="dtr-pricing__icon"><?php echo $image_html; ?></span>
                <?php } else { 
                        echo wp_kses_post( $settings['pricing_icon_img_html'] );
                } ?>
            </div>
			<?php if ( ! empty( $settings['pricing_title'] ) ) { ?>
            <h3 class="dtr-pricing__heading"><?php echo wp_kses_post( $settings['pricing_title'] ); ?></h3>
            <?php } ?>
            <?php if ( ! empty( $settings['pricing_description'] ) ) { ?>
            <div class="dtr-pricing__description"><?php echo wp_kses_post( $settings['pricing_description'] ) ?></div>
            <?php } ?>
			<?php if ( ! empty( $settings['pricing_price'] ) ) { ?>
            <p class="dtr-pricing__price"><span class="dtr-pricing__currency"><?php echo esc_html( $settings['pricing_currency'] ); ?></span><span class="dtr-pricing__price_value"><?php echo esc_html( $settings['pricing_price'] ); ?></span><span class="dtr-pricing__price_desc"><?php echo esc_html( $settings['pricing_desc'] ); ?></span></p>
            <?php } ?>
            <?php if ( ! empty( $settings['pricing_content'] ) ) { ?>
            <div class="dtr-pricing__content"><?php echo wp_kses_post( $settings['pricing_content'] ) ?></div>
            <?php } ?>
			<?php if ( ! empty( $settings['link_text'] ) ) { ?>
            <a <?php echo $this->get_render_attribute_string( 'button' ); ?>><span class="dtr-btn__text"><?php echo esc_html( $settings['link_text'] ); ?></span></a>
            <?php } ?>
		</div>
<?php	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
		<div class="dtr-pricing {{{settings.pricing_table_type }}}">
        	<# if ( settings.pricing_tagline ) { #>
            <div class="dtr-pricing__tagline">{{{ settings.pricing_tagline }}}</div>
            <# } #>
            <div class="dtr-pricing__icon-wrapper">
               <# if( settings.pricing_icon_img_type == 'dtr-icon-pricing-type-icon' ) {
               		iconHTML = elementor.helpers.renderIcon( view, settings.pricing_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
                    <span class="dtr-pricing__icon">{{{ iconHTML.value }}}</span>
               <# } else if( settings.pricing_icon_img_type == 'dtr-icon-pricing-type-img' )  {
                    var image = {
                        id: settings.image.id,
                        url: settings.image.url,
                        size: settings.image_size,
                        dimension: settings.image_custom_dimension,
                        model: view.getEditModel()
					};
					var image_url = elementor.imagesManager.getImageUrl( image ); #>
					<span class="dtr-pricing__icon"><img src="{{ image_url }}"/></span>
                <# } else { #>	
                {{{ settings.pricing_icon_img_html }}}
                 <# } #>	
            </div>
            <# if ( settings.pricing_title ) { #>
                <h4 class="dtr-pricing__heading">{{{ settings.pricing_title }}}</h4>
            <# } #>
            <# if ( settings.pricing_description ) { #>
            <div class="dtr-pricing__description">{{{ settings.pricing_description }}}</div>
            <# } #>          
            <# if ( settings.pricing_price ) { #>
             <p class="dtr-pricing__price"><span class="dtr-pricing__currency">{{{ settings.pricing_currency }}}</span><span class="dtr-pricing__price_value">{{{ settings.pricing_price }}}</span><span class="dtr-pricing__price_desc">{{{ settings.pricing_desc }}}</span></p>
            <# } #>            
            <# if ( settings.pricing_content ) { #>
            <div class="dtr-pricing__content">{{{ settings.pricing_content }}}</div>
            <# } #>  
            <# if ( settings.link_text ) { #>
                <a class="dtr-btn dtr-pricing__btn" href="{{ settings.link.url }}" role="button"><span class="dtr-btn__text">{{{ settings.link_text }}}</span></a> 
            <# } #> 
		</div>
		<?php
	}
}