<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Recentposts Carousel Widget
 */
class Narihealth_Recentposts_Carousel extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-posts-carousel';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Posts Carousel', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
	  	wp_register_script( 'swiper', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/swiper-bundle.min.js', [ 'elementor-frontend' ], '9.1.0', true );
		wp_register_script( 'dtr-widgets', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_style( 'swiper', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/css/swiper.min.css' );
    }
   
	/**
	 * Retrieve the list of scripts the image carousel widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
            'swiper',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Retrieve the list of styles the widget depends on.
	 * Used to set styles dependencies required to run the widget.
	 * @return array Widget styles dependencies.
	 */
	public function get_style_depends() {
        return [
			'swiper'
        ];
    }

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_post_carousel_content',
			[
				'label' => esc_html__( 'Posts Carousel', 'narihealth' ),
			]
		);
		
		$this->add_control(
			'post_limit',
			[
				'label' => esc_html__( 'Number of posts to show', 'narihealth' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 4,
				'min' => -1,
				'step' => 1,
				'separator' => 'before',
				'description' => esc_html__( '-1 to show all posts', 'narihealth' ),
			]
		);

		$this->add_control(
			'post_orderby',
			[
				'label' => esc_html__( 'Sort Posts By', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date' 	=> esc_html__( 'Date', 'narihealth' ),
					'rand' 	=> esc_html__( 'Random', 'narihealth' ),
					'title'	=> esc_html__( 'Title', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label' => esc_html__( 'Arrange Sorted Posts', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC'	=> esc_html__( 'Descending', 'narihealth' ),
					'ASC'  	=> esc_html__( 'Ascending', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'corner_type',
			[
				'label' => esc_html__( 'Corner Type', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dtr-post-block--rounded',
				'separator' => 'before',
				'options' => [
					'dtr-post-block--rounded'	=> esc_html__( 'Rounded', 'narihealth' ),
					''	=> esc_html__( 'Square', 'narihealth' ),
				],
			]
		);
		
		// nav_type
		$this->add_control(
			'nav_type',
			[
				'label' => esc_html__( 'Navigation Type', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'arrows',
				'separator' => 'before',
				'options' => [
					'arrows'	=> esc_html__( 'Arrow', 'narihealth' ),
					'dots' 		=> esc_html__( 'Dots', 'narihealth' ),
					'none' 		=> esc_html__( 'None', 'narihealth' ),
				],
			]
		);

		// image
		$this->add_control(
			'image_settings',
			[
				'label' => esc_html__( 'Image Settings', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'image',
			[
				'label' => esc_html__( 'Image', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'  	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'image_size',
			[
				'label' => esc_html__( 'Image Size', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'img_default',
				'options' => [
					'img_default'	=> esc_html__( 'Default', 'narihealth' ),
					'img_custom'	=> esc_html__( 'Custom - Hard Crop', 'narihealth' ),
				],
			]
		);
	
		$this->add_control(
			'image_size_default',
			[
				'label' => esc_html__( 'Choose Image Size', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'full',
				'condition' => [
					'image_size' => [ 'img_default' ],
				],
				'options' => [
					'full'		=> esc_html__( 'Full', 'narihealth' ),
					'medium'	=> esc_html__( 'Medium', 'narihealth' ),
					'thumbnail'	=> esc_html__( 'Thumbnail', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'img_crop_info',
			[
				'label' => esc_html__( 'While using cropping - size of main image must be greater than specified for cropping.', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'condition' => [
					'image_size' => [ 'img_custom' ],
				],
			]
		);
		
		$this->add_control(
			'img_width',
			[
				'label' => esc_html__( 'Hard Crop - Width ', 'narihealth' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 600,
				'condition' => [
					'image_size' => [ 'img_custom' ],
				],
				'min' => 100,
				'step' => 10,
				'separator' => 'none',
			]
		);
		
		$this->add_control(
			'img_height',
			[
				'label' => esc_html__( 'Hard Crop - Height ', 'narihealth' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 400,
				'condition' => [
					'image_size' => [ 'img_custom' ],
				],
				'min' => 100,
				'step' => 10,
				'separator' => 'none',
			]
		);	

		// content
		$this->add_control(
			'content_settings',
			[
				'label' => esc_html__( 'Content Settings', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'category',
			[
				'label' => esc_html__( 'Category', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'  	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'date',
			[
				'label' => esc_html__( 'Date', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'  => esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
				
		$this->add_control(
			'author',
			[
				'label' => esc_html__( 'Author', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'  => esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
					
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'  	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'excerpt',
			[
				'label' => esc_html__( 'Excerpt', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'  	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'words',
			[
				'label' 		=> esc_html__( 'Limit Short Content - Words Count', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '35',
				'label_block'	=> true,
				'show_label'	=> true,
				'condition' => [
					'excerpt' => [ 'show' ],
				],
			]
		);
		
		$this->add_control(
			'read_more',
			[
				'label' => esc_html__( 'Read More', 'insuran' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'separator' => 'before',
				'options' => [
					'show'	=> esc_html__( 'Show', 'insuran' ),
					'hide'	=> esc_html__( 'Hide', 'insuran' ),
				],
			]
		);
		
		// read_more_text
		$this->add_control(
			'read_more_text',
			[
				'label' 		=> esc_html__( 'Read More Text', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> esc_html__( 'Read More', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
			]
		);
		
        $this->add_control(
			'read_more_align',
			[
				'label' => esc_html__( 'Read More Text Align', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'align-right',
				'options' => [
					''	            => esc_html__( 'Left', 'narihealth' ),
					'align-right'   => esc_html__( 'Right', 'narihealth' ),
				],
			]
		);
        
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => esc_html__( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-post-block__title-link' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'main_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-post-block__title-link',
            ]
        );
		
		// meta
		$this->add_control(
			'meta_style',
			[
				'label' 	=> esc_html__( 'Date / Author', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'meta_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-item, {{WRAPPER}} .dtr-meta-item a' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'meta_border_color',
			[
				'label' 	=> esc_html__( 'Dot Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-item::before' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'meta_hover_color',
			[
				'label' 	=> esc_html__( 'Hover : Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-meta-item a:hover, {{WRAPPER}} .dtr-meta-item:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'meta_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-meta-item',
            ]
        );

		// Content
		$this->add_control(
			'content_style',
			[
				'label' => esc_html__( 'Content', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Excerpt Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-post-block__excerpt' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-post-block__excerpt',
            ]
        );
		
		// Read more
		$this->add_control(
			'read_more_style',
			[
				'label' => esc_html__( 'Read More', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
				
		$this->add_control(
			'link_text_color',
			[
				'label' 	=> esc_html__( 'Text Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text'	=> 'color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_color',
			[
				'label' 	=> esc_html__( 'Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_hover_color',
			[
				'label' 	=> esc_html__( 'On Hover: Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::after'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'link_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-link__text',
            ]
        );

		// nav_styles
		$this->add_control(
			'nav_styles',
			[
				'label' => esc_html__( 'Prev / Next Arrows', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
			]
		);
		
		$this->add_control(
			'arrow_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_border_color',
			[
				'label' => esc_html__( 'Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_hover_bg_color',
			[
				'label' => esc_html__( 'Hover Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_hover_border_color',
			[
				'label' => esc_html__( 'Hover Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_hover_color',
			[
				'label' => esc_html__( 'Hover Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
        // dots_nav_styles
		$this->add_control(
			'dots_nav_styles',
			[
				'label' => esc_html__( 'Pagination Dots', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
			]
		);   

		$this->add_control(
			'dots_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-pagination-bullet' => 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'dots_border_color',
			[
				'label' => esc_html__( 'Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet::after' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'dots_hover_bg_color',
			[
				'label' => esc_html__( 'Active / Hover Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet-active, {{WRAPPER}} .dtr-swiper .swiper-pagination-bullet:hover' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet:hover::after:' => 'border-color: {{VALUE}}; ',
				],
			]
		);

        $this->add_control(
			'dots_active_border_color',
			[
				'label' => esc_html__( 'Active Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet::before' => 'border-color: {{VALUE}};',
				],
			]
		);
        
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings_for_display();
		echo do_shortcode('[dtr_recentposts limit="' . $settings['post_limit'] . '" orderby="' . $settings['post_orderby'] . '" order="' . $settings['post_order'] . '" corner_type="' . $settings['corner_type'] . '" words="' . $settings['words'] . '" image="' . $settings['image'] . '" title="' . $settings['title'] . '" category="' . $settings['category'] . '" date="' . $settings['date'] . '" author="' . $settings['author'] . '" excerpt="' . $settings['excerpt'] . '" image_size="' . $settings['image_size'] . '" image_size_default="' . $settings['image_size_default'] . '" img_width="' . $settings['img_width'] . '" img_height="' . $settings['img_height'] . '" nav_type="' . $settings['nav_type'] . '" read_more="' . $settings['read_more'] . '" read_more_align="' . $settings['read_more_align'] . '" read_more_text="' . $settings['read_more_text'] . '" ]');
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() { }
}