<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Section Intro Widget
 */
class Narihealth_Section_Intro extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-section-intro';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Section Intro', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_section_intro_content',
			[
				'label'	=> esc_html__( 'Section Intro', 'narihealth' ),
			]
		);
		
		// text align
		$this->add_control(
			'text_align',
			[
				'label' 	=> esc_html__( 'Text Align', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'text-left',
				'options'	=> [
					'text-center'	=> esc_html__( 'Center', 'narihealth' ),
					'text-left'		=> esc_html__( 'Left', 'narihealth' ),
					'text-right'    => esc_html__( 'Right', 'narihealth' ),
				],
			]
		);

		// heading
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
				
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h2',
			]
		);
		
		// subheading
		$this->add_control(
			'subheading',
			[
				'label' 		=> esc_html__( 'Sub Text', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Sub Text Goes Here', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Sub Text Goes Here', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
		
		// content
		$this->add_control(
			'content',
			[
				'label' 		=> esc_html__( 'Intro Content', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Content Goes Here', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Content Goes Here', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);

		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'narihealth' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_section_intro_style',
			[
				'label'	=> esc_html__( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		// subheading
		$this->add_control(
			'subheading_style_control',
			[
				'label'	=> esc_html__( 'Sub Text', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
			]
		);
		
		$this->add_control(
			'subheading_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-section-intro__subheading'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'subheading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-section-intro__subheading',
            ]
        );
		
		// heading
		$this->add_control(
			'heading_style_control',
			[
				'label'	=> esc_html__( 'Heading', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-section-intro__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'heading_span_color',
			[
				'label' 	=> esc_html__( 'Span in Heading Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-section-intro__heading span'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-section-intro__heading',
            ]
        );
		
		// content
		$this->add_control(
			'content_style_control',
			[
				'label'	=> esc_html__( 'Content', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-section-intro__content'	=> 'color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'content_span_color',
			[
				'label' 	=> esc_html__( 'Span in Content Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-section-intro__content span'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-section-intro__content',
            ]
        );
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
	$settings = $this->get_settings(); ?>
    <div class="dtr-section-intro <?php echo esc_attr( $settings['text_align'] ) ?>">
    	<?php if ( ! empty( $settings['subheading'] ) ) { ?>
           <p class="dtr-section-intro__subheading"><?php echo wp_kses_post( $settings['subheading'] ); ?></p>
        <?php } ?>
        <?php if ( ! empty( $settings['heading'] ) ) { ?>
        	<<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-section-intro__heading"><?php echo wp_kses_post( $settings['heading'] ) ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
        <?php } ?>
        <?php if ( ! empty( $settings['content'] ) ) { ?>
        	<p class="dtr-section-intro__content"><?php echo wp_kses_post( $settings['content'] ) ?></p>
        <?php } ?>
    </div>
<?php }

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <div class="dtr-section-intro {{ settings.text_align }}">
        <# if ( settings.subheading != '' ) { #>
        <p class="dtr-section-intro__subheading"> {{{ settings.subheading }}}</p>
        <# } #>
        <# if ( settings.heading != '' ) { #>
        <{{ settings.heading_size }} class="dtr-section-intro__heading"> {{{ settings.heading }}}</{{ settings.heading_size }}>
        <# } #>
        <# if ( settings.content != '' ) { #>
        <div class="dtr-section-intro__content">{{{ settings.content }}}</div>
        <# } #>
        </div>    
		<?php
	}
}