<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Servicebox_Carousel extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-servicebox-carousel';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Servicebox Carousel', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
    
    /**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
	  	wp_register_script( 'swiper', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/swiper-bundle.min.js', [ 'elementor-frontend' ], '6.8.0', true );
		wp_register_script( 'dtr-widgets', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_style( 'swiper', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/css/swiper.min.css' );
    }
	
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
			'swiper',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_servicebox_carousel',
			[
				'label' => __( 'Servicebox Carousel', 'narihealth' ),
			]
		);
        
         $this->add_control(
			'border_radius',
			[
				'label' 	=> esc_html__( 'Border Radius', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '',
				'options'	=> [
					''	                    => esc_html__( 'Rounded', 'narihealth' ),
					'dtr-square-corners'    => esc_html__( 'Square', 'narihealth' ),
				],
			]
		);
        
        // nav_type
		$this->add_control(
			'nav_type',
			[
				'label' => esc_html__( 'Navigation Type', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dots',
				'separator' => 'before',
				'options' => [
					'arrows'	=> esc_html__( 'Arrow', 'narihealth' ),
					'dots' 		=> esc_html__( 'Dots', 'narihealth' ),
					'none' 		=> esc_html__( 'None', 'narihealth' ),
				],
			]
		);
        
        $this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h4',
                'separator' 	=> 'after',
			]
		);
		
		$repeater = new Repeater();
        
        // image
		$repeater->add_control(
			'servicebox_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
			]
		);	
			
		$repeater->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'narihealth' ),
				'type' 		=> Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default'	=> [
					'url'	=> Utils::get_placeholder_image_src(),
				],
			]
		);
		
		$repeater->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
        
		$repeater->add_control(
			'servicebox_heading',
			[
				'label' 		=> esc_html__( 'Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
        
        // content
		$repeater->add_control(
			'servicebox_content',
			[
				'label' 		=> esc_html__( 'Content', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> 'Content Goes Here',
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'narihealth' ),
				'label_block' 	=> true,
			]
		);
		
        $repeater->add_control(
			'link_text',
			[
				'label' 		=> esc_html__( 'Link Text', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Learn More', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Learn More', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		); 

		$repeater->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'narihealth' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default'	=> [
					'url'	=> '#',
				],
			]
		);

		$this->add_control(
			'servicebox_list',
			[
				'label' => __( 'Servicebox Items', 'narihealth' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'servicebox_heading' => __( 'Heading #1', 'narihealth' ),
					],
					[
						'servicebox_heading' => __( 'Heading #2', 'narihealth' ),
					],
					[
						'servicebox_heading' => __( 'Heading #3', 'narihealth' ),
					],
				],
				'title_field' => '{{{ servicebox_heading }}}',
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'narihealth' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'narihealth' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'box_bg_color',
			[
				'label' 	=> esc_html__( 'Box Background Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox'	=> 'background-color: {{VALUE}};',
				],
			]
		);
        
        // heading
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox__heading',
            ]
        );
        
        // content
		$this->add_control(
			'content_style_control',
			[
				'label' 	=> esc_html__( 'Content', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__content'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox__content',
            ]
        );
        
         // link
		$this->add_control(
			'link_style_control',
			[
				'label' 	=> esc_html__( 'Link', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
        
		$this->add_control(
			'link_text_color',
			[
				'label' 	=> esc_html__( 'Text Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text'	=> 'color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_color',
			[
				'label' 	=> esc_html__( 'Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_hover_color',
			[
				'label' 	=> esc_html__( 'On Hover: Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::after'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'link_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-link__text',
            ]
        );
        
        // nav_styles
		$this->add_control(
			'nav_styles',
			[
				'label' => esc_html__( 'Prev / Next Arrows', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
			]
		);
		
		$this->add_control(
			'arrow_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_border_color',
			[
				'label' => esc_html__( 'Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_hover_bg_color',
			[
				'label' => esc_html__( 'Hover Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_hover_border_color',
			[
				'label' => esc_html__( 'Hover Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'arrow_hover_color',
			[
				'label' => esc_html__( 'Hover Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'arrows' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'color: {{VALUE}};',
				],
			]
		);
		
        // dots_nav_styles
		$this->add_control(
			'dots_nav_styles',
			[
				'label' => esc_html__( 'Pagination Dots', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
			]
		);   

		$this->add_control(
			'dots_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-pagination-bullet' => 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'dots_border_color',
			[
				'label' => esc_html__( 'Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet::after' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'dots_hover_bg_color',
			[
				'label' => esc_html__( 'Active / Hover Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet-active, {{WRAPPER}} .dtr-swiper .swiper-pagination-bullet:hover' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet:hover::after:' => 'border-color: {{VALUE}}; ',
				],
			]
		);

        $this->add_control(
			'dots_active_border_color',
			[
				'label' => esc_html__( 'Active Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet::before' => 'border-color: {{VALUE}};',
				],
			]
		);
        
		$this->end_controls_section();
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		?>
        <?php
        if( $settings['nav_type']  == 'arrows' ) {
            $nav_class = 'dtr-slider-has-arrows';
        } elseif( $settings['nav_type']  == 'dots' ) {
            $nav_class = 'dtr-slider-has-dots';	
        } else {   
            $nav_class = ''; 
        }
        ?>
        <div class="swiper swiper-container dtr-swiper dtr-servicebox-carousel dtr-servicebox-carousel-3col <?php echo $settings['border_radius']; ?> <?php echo esc_attr($nav_class); ?> clearfix"><div class="swiper-wrapper">
        <?php
        foreach ( $settings['servicebox_list'] as $index => $item ) :
            $servicebox_heading_setting_key = $this->get_repeater_setting_key( 'servicebox_heading', 'servicebox_list', $index );
            $this->add_render_attribute( $servicebox_heading_setting_key, 'class', 'dtr-servicebox__heading' );
            $this->add_inline_editing_attributes( $servicebox_heading_setting_key ); 
            $servicebox_content_setting_key = $this->get_repeater_setting_key( 'servicebox_content', 'servicebox_list', $index );
            $this->add_render_attribute( $servicebox_content_setting_key, 'class', 'dtr-servicebox__content' );
            $this->add_inline_editing_attributes( $servicebox_content_setting_key ); 
            $servicebox_linktext_setting_key = $this->get_repeater_setting_key( 'link__text', 'servicebox_list', $index );
            $this->add_render_attribute( $servicebox_linktext_setting_key, 'class', 'dtr-link__text' );
            $this->add_inline_editing_attributes( $servicebox_linktext_setting_key ); 
            ?>
            <div class="swiper-slide clearfix">
            <div class="dtr-servicebox">
                <?php if ( ! empty( $item['image']['url'] ) ) { ?>
                    <div class="dtr-servicebox__img">
                    <?php
                    $this->add_render_attribute( 'image', 'src', $item['image']['url'] );
                    $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $item['image'] ) );
                    $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $item['image'] ) );
                    $image_html = Group_Control_Image_Size::get_attachment_image_html( $item, 'thumbnail', 'image' );
                    echo $image_html; ?>
                    </div> 
                <?php } ?>
                <div class="dtr-servicebox__content-wrap">
                    <<?php echo esc_attr( $settings['heading_size'] ) ?> <?php echo $this->get_render_attribute_string( $servicebox_heading_setting_key ); ?>><?php echo $item['servicebox_heading']; ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
                    <div <?php echo $this->get_render_attribute_string( $servicebox_content_setting_key ); ?>><?php echo wp_kses_post( $item['servicebox_content'] ); ?></div>
                    <div class="dtr-servicebox__link-wrap">
                    <?php
                    if ( ! empty( $item['link']['url'] ) ) {
                        $link_key = 'link_' . $index;
                        $this->add_link_attributes( $link_key, $item['link'] );
                        echo '<a class="dtr-link" ' . $this->get_render_attribute_string( $link_key ) . '>';
                    } 
                    ?>
                    <span <?php echo $this->get_render_attribute_string( $servicebox_linktext_setting_key ); ?>><?php echo $item['link_text']; ?></span>
                    <?php if ( ! empty( $item['link']['url'] ) ) { ?>
                        </a>
                    <?php } ?>
                    </div>
                </div>
            </div>
            </div>
        <?php endforeach; ?>
    </div>
    <?php if( $settings['nav_type']  == 'arrows' ) { ?>
            <div class="swiper-button-prev dtr-swiper-button dtr-servicebox__prev"></div><div class="swiper-button-next dtr-swiper-button dtr-servicebox__next"></div>
    <?php } ?>
    <?php if( $settings['nav_type']  == 'dots' ) { ?>
            <div class="swiper-pagination dtr-servicebox__dots"></div>
    <?php } ?>
    </div>
<?php	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>       
        <# if ( settings.nav_type == 'arrows' ) { 
            $nav_class = 'dtr-slider-has-arrows';
        } 
        else if ( settings.nav_type == 'dots' ) { 
            $nav_class = 'dtr-slider-has-dots';
        } else { 
            $nav_class = '';
        } #>
        <# if ( settings.servicebox_list ) { #>
            <div class="swiper swiper-container dtr-swiper dtr-servicebox-carousel-3col {{ settings.border_radius }} {{{ $nav_class }}} clearfix"><div class="swiper-wrapper">
            <# _.each( settings.servicebox_list, function( item, index ) { #>
                <div class="swiper-slide clearfix">
                    <div class="dtr-servicebox">
                        <#	if ( item.image.url ) { #>
                            <div class="dtr-servicebox__img">
                            <# var image = {
                            id: item.image.id,
                            url: item.image.url,
                            size: item.thumbnail_size,
                            dimension: item.thumbnail_custom_dimension,
                            model: view.getEditModel()
                            };
                            var image_url = elementor.imagesManager.getImageUrl( image ); #> 
                            <img src="{{ image_url }}"/> 
                            </div>
                        <# } #>
                        <div class="dtr-servicebox__content-wrap">
                            <# if ( item.servicebox_heading != '' ) { #>
                                <{{ settings.heading_size }} class="dtr-servicebox__heading"> {{{ item.servicebox_heading }}}</{{ settings.heading_size }}>
                            <# } #>
                            <# if ( item.servicebox_content != '' ) { #>
                                <div class="dtr-servicebox__content"> {{{ item.servicebox_content }}}</div>
                            <# } #>
                            <div class="dtr-servicebox__link-wrap">
                                <# if ( item.link && item.link.url ) { #>
                                    <a class="dtr-link" href="{{ item.link.url }}">
                                <# } #>
                                <span class="dtr-link__text">{{{ item.link_text }}}</span>
                                <# if ( item.link && item.link.url ) { #>
                                    </a>
                                <# } #>
                            </div>
                        </div>
                    </div>    
                </div>  
            <# } ); #>
            </div>
            <# if ( settings.nav_type == 'arrows' ) { #>
                <div class="swiper-button-prev dtr-swiper-button dtr-servicebox__prev"></div><div class="swiper-button-next dtr-swiper-button dtr-servicebox__next"></div>
            <#  } #>
            <# if ( settings.nav_type == 'dots' ) { #>
                <div class="swiper-pagination dtr-servicebox__dots"></div>
            <#  } #>
            </div>
        <#	} #>
		<?php
	}
}