<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Icons_Manager;
use Elementor\Control_Media;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Servicebox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-servicebox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Service Box', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_servicebox',
			[
				'label' => __( 'Service Box', 'narihealth' ),
			]
		);
		
		$this->add_control(
			'servicebox_icon_type',
			[
				'label' 	=> esc_html__( 'Icon Type', 'narihealth' ),
				'type'		=> Controls_Manager::SELECT,
				'default'	=> 'icon-type-icon',
				'separator'	=> 'before',
				'options' 	=> [
					'icon-type-icon'		=> esc_html__( 'Font Awesome Icon', 'narihealth' ),
					'icon-type-img'			=> esc_html__( 'Image', 'narihealth' ),
					'icon-type-custom-icon'	=> esc_html__( 'Theme Icon', 'narihealth' ),
					'icon-type-html'		=> esc_html__( 'Custom HTML', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'narihealth' ),
				'type' => Controls_Manager::SLIDER,
				'separator' => 'before',
				'range' => [
					'px' => [
						'max' => 200,
					],
				],
				'default' => [
					'size' => 48,
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-servicebox__icon' => 'font-size: {{SIZE}}{{UNIT}}',
				],
			]
		);
		
		$this->add_control(
			'default_icon',
			[
				'label' => esc_html__( 'Font Awesome Library', 'narihealth' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
				'label_block' => true,
				'condition' => [
					'servicebox_icon_type' => [ 'icon-type-icon' ],
				],
			]
		);

		$this->add_control(
			'custom_icon',
			[
				'label' => esc_html__( 'Theme Custom Library', 'narihealth' ),
				'type' => Controls_Manager::SELECT2,
				'default' => 'icon-star-solid',
				'label_block' => true,
				'condition' => [
					'servicebox_icon_type'	=> [ 'icon-type-custom-icon' ],
				],
				'description' => esc_html__( 'Icon demo file for extra icons is included in help document.', 'narihealth' ),
				'options' => dtr_icons(),
			]
		);
		
		$this->add_control(
			'servicebox_image_control',
			[
				'label' 	=> esc_html__( 'Image', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'condition' => [
					'servicebox_icon_type'	=> [ 'icon-type-img' ],
				],
			]
		);	
			
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'narihealth' ),
				'type' 		=> Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default'	=> [
					'url'	=> NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/img/img-circle-100x100.png',
				],
				'condition'	=> [
					'servicebox_icon_type'	=> [ 'icon-type-img' ],
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
				'condition' => [
					'servicebox_icon_type'	=> [ 'icon-type-img' ],
				],
			]
		);
		
		$this->add_control(
			'servicebox_icon_html',
			[
				'label' => __( 'Custom HTML', 'narihealth' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'label_block' => true,
				'condition' => [
					'servicebox_icon_type'	=> [ 'icon-type-html' ],
				],
			]
		);
		
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		); 
		
		$this->add_control(
			'subtext',
			[
				'label' 		=> esc_html__( 'Subtext in Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( '.01', 'narihealth' ),
				'placeholder' 	=> esc_html__( '.01', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		); 
				
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h4',
			]
		);
		
		$this->add_control(
			'servicebox_box_content',
			[
				'label' 		=> esc_html__( 'Content', 'narihealth' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'default' 		=> esc_html__( 'Content Goes Here', 'narihealth' ),
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'narihealth' ),
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'narihealth' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'narihealth' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'box_bg_color',
			[
				'label' => __( 'Box Background Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-servicebox' 		=> 'background-color: {{VALUE}};',
					'{{WRAPPER}} .dtr-servicebox__icon' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'inner_box_bg_color',
			[
				'label' => __( 'Inner Box Background Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-servicebox__icon, {{WRAPPER}} .dtr-servicebox__content'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'icon_style_control',
			[
				'label' 	=> esc_html__( 'Icon', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Color', 'narihealth' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-servicebox__icon' => 'color: {{VALUE}};',
				],
			]
		);
		
		// heading
		$this->add_control(
			'heading_style_control',
			[
				'label' 	=> esc_html__( 'Heading', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__heading'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'heading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox__heading',
            ]
        );
		
		$this->add_control(
			'subtext_style_control',
			[
				'label' 	=> esc_html__( 'Sub Text in Heading', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'sutext_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__subtext'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'subtext_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox__subtext',
            ]
        );
		
		// content
		$this->add_control(
			'content_style_control',
			[
				'label' 	=> esc_html__( 'Content', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__text'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'content_link_color',
			[
				'label' 	=> esc_html__( 'Link in Content - Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__text a'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'content_link_hover_color',
			[
				'label' 	=> esc_html__( 'Hover to Link in Content - Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox__text a:hover'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'content_list_icon_color',
			[
				'label' 	=> esc_html__( 'List Icon Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-servicebox ul li::before'	=> 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-servicebox__text',
            ]
        );

		$this->end_controls_section();
	}

		/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		// icon
		if ( ! empty( $settings['custom_icon'] ) ) {
			$this->add_render_attribute( 'custom_icon', 'class', $settings['custom_icon'] );
			$this->add_render_attribute( 'custom_icon', 'aria-hidden', 'true' );
		}
		?>
        <div class="dtr-servicebox">
        <div class="dtr-icon dtr-servicebox__icon">
			<?php if ( $settings['servicebox_icon_type'] == 'icon-type-icon' && ! empty( $settings['default_icon'] ) ) { 
                Icons_Manager::render_icon( $settings['default_icon'], [ 'aria-hidden' => 'true' ] ); 
            } elseif ( $settings['servicebox_icon_type'] == 'icon-type-custom-icon' && ! empty( $settings['custom_icon'] ) ) { ?>
                <i <?php echo $this->get_render_attribute_string( 'custom_icon' ); ?>></i>
            <?php } elseif ( $settings['servicebox_icon_type'] == 'icon-type-img' && ! empty( $settings['image']['url'] ) ) { 
                $this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
                $this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
                $this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
                $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
                echo $image_html;
            } elseif ( $settings['servicebox_icon_type'] == 'icon-type-html' && ! empty( $settings['servicebox_icon_html'] ) ) {
                echo wp_kses_post( $settings['servicebox_icon_html'] );
            } else {}  ?>     
        </div>
        <div class="dtr-servicebox__content">
			<?php if ( ! empty( $settings['heading'] ) ) { ?>
                <<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-servicebox__heading"><span class="dtr-servicebox__subtext"><?php echo wp_kses_post( $settings['subtext'] ); ?></span> <?php echo wp_kses_post( $settings['heading'] ); ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
            <?php } ?>
            <?php if ( ! empty( $settings['servicebox_box_content'] ) ) { ?>
                 <div class="dtr-servicebox__text"><?php echo wp_kses_post( $settings['servicebox_box_content'] ) ?></div>
            <?php } ?>
        </div>
        </div>
<?php	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
        <# iconHTML = elementor.helpers.renderIcon( view, settings.default_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>
        <div class="dtr-servicebox">
            <div class="dtr-icon dtr-servicebox__icon">
                <# if ( settings.servicebox_icon_type == 'icon-type-icon' ) { #>
                    {{{ iconHTML.value }}}
                <# } else if ( settings.servicebox_icon_type == 'icon-type-custom-icon' ) { #>
                    <i class="{{ settings.custom_icon }}"></i> 	
                <# } else if ( settings.servicebox_icon_type == 'icon-type-img' ) { #>
                    <#
                    var image = {
                    id: settings.image.id,
                    url: settings.image.url,
                    size: settings.thumbnail_size,
                    dimension: settings.thumbnail_custom_dimension,
                    model: view.getEditModel()
                    };
                    var image_url = elementor.imagesManager.getImageUrl( image );  #> 
                    <img src="{{ image_url }}"/> 
                <# } else if ( settings.servicebox_icon_type == 'icon-type-html' ) { #>
                    {{{ settings.servicebox_icon_html }}}
                <# } else { } #>
            </div>
            <div class="dtr-servicebox__content">
                <{{ settings.heading_size }} class="dtr-servicebox__heading"><span class="dtr-servicebox__subtext">{{{ settings.subtext }}}</span> {{{ settings.heading }}}</{{ settings.heading_size }}>
                 <# if ( settings.servicebox_box_content != '' ) { #>
                <div class="dtr-servicebox__text">{{{ settings.servicebox_box_content }}}</div>
                <# } #>
            </div>
        </div> 
		<?php
	}
}