<?php
namespace NarihealthAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Team Widget
 */
class Narihealth_Team extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-team';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Member', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		$this->start_controls_section(
			'section_team_control',
			[
				'label'	=> esc_html__( 'Team', 'narihealth' ),
			]
		);
        
        $this->add_control(
			'border_radius',
			[
				'label' 	=> esc_html__( 'Border Radius', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '',
				'options'	=> [
					''	                    => esc_html__( 'Rounded', 'narihealth' ),
					'dtr-square-corners'    => esc_html__( 'Square', 'narihealth' ),
				],
			]
		);
        
        
		$this->add_control(
			'team_image_control',
			[
				'label' => esc_html__( 'Image', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
				
		$this->add_control(
			'image',
			[
				'label' 	=> esc_html__( 'Choose Image', 'narihealth' ),
				'type' 		=> Controls_Manager::MEDIA,
				'default'	=> [
					'url'	=> NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/img/img-square-dark-600x300.png',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' 		=> 'thumbnail',
				'default' 	=> 'full',
				'separator'	=> 'none',
			]
		);
		
		// heading
		$this->add_control(
			'heading',
			[
				'label' 		=> esc_html__( 'Heading', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Heading Goes Here', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);
				
		$this->add_control(
			'heading_size',
			[
				'label' 	=> esc_html__( 'Heading - HTML Tag', 'elementor' ),
				'type' 		=> Controls_Manager::SELECT,
				'options'	=> [
					'h1' 	=> 'H1',
					'h2' 	=> 'H2',
					'h3' 	=> 'H3',
					'h4' 	=> 'H4',
					'h5' 	=> 'H5',
					'h6'	=> 'H6',
					'p' 	=> 'p',
				],
				'default' => 'h5',
			]
		);

		// content
		$this->add_control(
			'team_content',
			[
				'label' 		=> esc_html__( 'Content', 'narihealth' ),
				'type' 			=> Controls_Manager::WYSIWYG,
				'default' 		=> '',
				'separator'		=> 'before',
				'placeholder' 	=> esc_html__( 'Your Content', 'narihealth' ),
				'default' 		=> '',
				'label_block' 	=> true,
			]
		);
        
        // link
		$this->add_control(
			'team_link_control',
			[
				'label' 	=> esc_html__( 'Link', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);		
		
		$this->add_control(
			'link_text',
			[
				'label' 		=> esc_html__( 'Link Text', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> esc_html__( 'Learn More', 'narihealth' ),
				'placeholder' 	=> esc_html__( 'Learn More', 'narihealth' ),
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		); 

		$this->add_control(
			'member_link',
			[
				'label' 		=> esc_html__( 'Link', 'narihealth' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder'	=> 'http://your-link.com',
				'default'	=> [
					'url'	=> '#',
				],
			]
		);
        
        // social
		$this->add_control(
			'social_controls',
			[
				'label' => esc_html__( 'Social', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        
        $this->add_control(
			'team_social',
			[
				'label' 	=> esc_html__( 'Social', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'options'	=> [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'social_icon',
			[
				'label' 			=> __( 'Icon', 'elementor' ),
				'type' 				=> Controls_Manager::ICONS,
				'fa4compatibility'	=> 'social',
				'label_block'		=> true,
				'default'			=> [
					'value'		=> 'fab fa-wordpress',
					'library'	=> 'fa-brands',
				],
				'recommended'		=> [
					'fa-brands'	=> [
						'android',
						'apple',
						'behance',
						'bitbucket',
						'codepen',
						'delicious',
						'deviantart',
						'digg',
						'dribbble',
						'elementor',
						'facebook',
						'flickr',
						'foursquare',
						'free-code-camp',
						'github',
						'gitlab',
						'globe',
						'google-plus',
						'houzz',
						'instagram',
						'jsfiddle',
						'linkedin',
						'medium',
						'meetup',
						'mixcloud',
						'odnoklassniki',
						'pinterest',
						'product-hunt',
						'reddit',
						'shopping-cart',
						'skype',
						'slideshare',
						'snapchat',
						'soundcloud',
						'spotify',
						'stack-overflow',
						'steam',
						'stumbleupon',
						'telegram',
						'thumb-tack',
						'tripadvisor',
						'tumblr',
						'twitch',
						'twitter',
						'viber',
						'vimeo',
						'vk',
						'weibo',
						'weixin',
						'whatsapp',
						'wordpress',
						'xing',
						'yelp',
						'youtube',
						'500px',
					],
					'fa-solid'	=> [
						'envelope',
						'link',
						'rss',
					],
				],
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'elementor' ),
				'type' 			=> Controls_Manager::URL,
				'label_block'	=> true,
				'default'		=> [
					'is_external'	=> 'true',
				],
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'elementor' ),
			]
		);

		$this->add_control(
			'social_icon_list',
			[
				'label' 		=> __( 'Social Icons', 'elementor' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields'		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'social_icon'	=> [
							'value' 	=> 'fab fa-twitter',
							'library' 	=> 'fa-brands',
						],
					],
				],
				'title_field'	=> '',
			]
		);
        // social ends
        
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'narihealth' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'narihealth' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'box_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		// heading
		$this->add_control(
			'heading_style',
			[
				'label' => esc_html__( 'Heading', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'heading_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team__heading'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'team_heading_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-team__heading',
            ]
        );
		
		// content
		$this->add_control(
			'content_style',
			[
				'label' => esc_html__( 'Content', 'narihealth' ),
				'type' 	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-team__content'	=> 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'content_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-team__content',
            ]
        );
		
        // link
		$this->add_control(
			'team_link_style_control',
			[
				'label' 	=> esc_html__( 'Link', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);

		$this->add_control(
			'link_text_color',
			[
				'label' 	=> esc_html__( 'Text Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text'	=> 'color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_color',
			[
				'label' 	=> esc_html__( 'Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-link__text::before'	=> 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'link_line_hover_color',
			[
				'label' 	=> esc_html__( 'On Hover: Line Color', 'narihealth' ),
				'type' 		=> Controls_Manager::COLOR,
				'default' 	=> '',
				'selectors'	=> [
					'{{WRAPPER}}.dtr-link__text::after'	=> 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'link_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-link__text',
            ]
        );
        
		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
         // link
		if ( ! empty( $settings['member_link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['member_link'] );
		}
		$this->add_render_attribute( 'button', 'role', 'button' );
	  	?>
    <div class="dtr-team <?php echo $settings['border_radius']; ?>">
        <?php if ( ! empty( $settings['image']['url'] ) ) { 
			$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
			$image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' ); ?>
			<div class="dtr-team__img">
            <?php echo $image_html ?>
            <!-- team social starts -->
                <?php if ( $settings['team_social'] == 'show' ) { ?>
                    <div class="dtr-team__social">
                        <?php
                        foreach ( $settings['social_icon_list'] as $index => $item ) {
                            
                        $link_key = 'link_' . $index;
                        $this->add_render_attribute( $link_key, 'href', $item['link']['url'] );
                        $this->add_render_attribute( $link_key, 'class', [
                            'dtr-team__social-icon',
                            'elementor-repeater-item-' . $item['_id'],
                        ] );
        
                        if ( $item['link']['is_external'] ) {
                            $this->add_render_attribute( $link_key, 'target', '_blank' );
                        }
        
                        if ( $item['link']['nofollow'] ) {
                            $this->add_render_attribute( $link_key, 'rel', 'nofollow' );
                        }
        
                        ?>
                        <a <?php echo $this->get_render_attribute_string( $link_key ); ?>>
                            <?php Icons_Manager::render_icon( $item['social_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                        </a>
                        <?php } ?>
                    </div>
                <?php } ?>
                <!-- team social -->  
            </div>
        <?php } ?>
        <div class="dtr-team__content-wrap">
            <?php if ( ! empty( $settings['heading'] ) ) { ?>
                <<?php echo esc_attr( $settings['heading_size'] ) ?> class="dtr-team__heading"><?php echo wp_kses_post( $settings['heading'] ); ?></<?php echo esc_attr( $settings['heading_size'] ) ?>>
            <?php } ?>
            <?php if ( ! empty( $settings['team_content'] ) ) { ?>
                <div class="dtr-team__content"><?php echo wp_kses_post( $settings['team_content'] ) ?></div>
            <?php } ?>
            <?php if ( ! empty( $settings['link_text'] ) ) { ?>
                <div class="dtr-team__link-wrap">
                    <a class="dtr-link" <?php echo $this->get_render_attribute_string( 'button' ); ?>>
                    <span class="dtr-link__text"><?php echo esc_html( $settings['link_text'] ); ?></span>
                    </a>
                </div>
            <?php } ?>
        </div>
    </div>
<?php
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
		?>
    <div class="dtr-team {{ settings.border_radius }}">
    	<# var iconsHTML = {}; #>
        <#	if ( settings.image.url ) { #>
            <# var image = {
            id: settings.image.id,
            url: settings.image.url,
            size: settings.thumbnail_size,
            dimension: settings.thumbnail_custom_dimension,
            model: view.getEditModel() };
            var image_url = elementor.imagesManager.getImageUrl( image );  #><div class="dtr-team__img">
            <img src="{{ image_url }}"/>
                <# if ( settings.team_social == 'show' ) { #>
                <div class="dtr-team__social">
                    <# _.each( settings.social_icon_list, function( item, index ) {
                        var link = item.link ? item.link.url : '' #>
                        <a class="dtr-team__social-icon elementor-repeater-item-{{item._id}}" href="{{ link }}">
                        <# iconsHTML[ index ] = elementor.helpers.renderIcon( view, item.social_icon, { 'aria-hidden': true }, 'i', 'object' ); #>
                        {{{ iconsHTML[ index ].value }}}
                        </a>
                    <# } ); #>
                </div>
                <# } #>
            </div>
        <# } #>
        <div class="dtr-team__content-wrap">
            <# if ( settings.heading != '' ) { #>
                <{{ settings.heading_size }} class="dtr-team__heading"> {{{ settings.heading }}}</{{ settings.heading_size }}>
            <# } #>
            <# if ( settings.team_content != '' ) { #>
                <div class="dtr-team__content">{{{ settings.team_content }}}</div>
            <# } #>
            <# if ( settings.member_link.url != '' ) { #> 
                <div class="dtr-team__link-wrap">
                    <a class="dtr-link" href="{{ settings.member_link.url }}" role="button">
                        <span class="dtr-link__text">{{{ settings.link_text }}}</span>
                    </a>
                </div> 
            <# } #>
        </div>
    </div>
<?php
	}
}