<?php
namespace NarihealthAddons\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Testimonial Carousel Widget
 */
class Narihealth_Testimonial_Carousel extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-testimonial-carousel';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonial Carousel', 'narihealth' );
	}
 
	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
	  	wp_register_script( 'swiper', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/swiper-bundle.min.js', [ 'elementor-frontend' ], '6.8.0', true );
		wp_register_script( 'dtr-widgets', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_style( 'swiper', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/css/swiper.min.css' );
    }
	
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
			'swiper',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Retrieve the list of styles the widget depends on.
	 * Used to set styles dependencies required to run the widget.
	 * @return array Widget styles dependencies.
	 */
	public function get_style_depends() {
        return [
			'swiper'
        ];
    }

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_testimonial_content',
			[
				'label' => esc_html__( 'Testimonial Carousel', 'narihealth' ),
			]
		);
		
		$this->add_control(
			'slider_col',
			[
				'label' 		=> esc_html__( 'Columns', 'narihealth' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'dtr-testimonial-carousel-1col',
				'label_block'	=> true,
				'options'	=> [
					'dtr-testimonial-carousel-1col' 	=> esc_html__( 'Single Column', 'narihealth' ),
					'dtr-testimonial-carousel-2col' 	=> esc_html__( '2 Columns', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'post_limit',
			[
				'label' 		=> esc_html__( 'Number of posts to show', 'narihealth' ),
				'description'	=> esc_html__( '-1 to show all posts', 'narihealth' ),
				'type' 			=> Controls_Manager::NUMBER,
				'default'		=> '-1',
				'min' 			=> -1,
				'step' 			=> 1,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'post_orderby',
			[
				'label' 		=> esc_html__( 'Sort Testimonials By', 'narihealth' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'date',
				'label_block'	=> true,
				'options'	=> [
					'date' 	=> esc_html__( 'Date', 'narihealth' ),
					'rand' 	=> esc_html__( 'Random', 'narihealth' ),
					'title'	=> esc_html__( 'Title', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label' 		=> esc_html__( 'Arrange Sorted Testimonials', 'narihealth' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> 'DESC',
				'label_block'	=> true,
				'options'	=> [
					'DESC'	=> esc_html__( 'Descending', 'narihealth' ),
					'ASC'  	=> esc_html__( 'Ascending', 'narihealth' ),
				],
			]
		);
        
        $this->add_control(
			'stars',
			[
				'label' 	=> esc_html__( 'Stars', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'separator'	=> 'before',
				'options' 	=> [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
        
		$this->add_control(
			'review_image_display',
			[
				'label' 	=> esc_html__( 'Review Platform Image', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'separator'	=> 'before',
				'options' 	=> [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
	
		// nav_type
		$this->add_control(
			'nav_type',
			[
				'label' => esc_html__( 'Navigation Dots', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'dots',
				'separator' => 'before',
				'options' => [
					'dots'  => esc_html__( 'Show', 'narihealth' ),
					'none'  => esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' 	=> esc_html__( 'View', 'narihealth' ),
				'type' 		=> Controls_Manager::HIDDEN,
				'default'	=> 'traditional',
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'narihealth' ),
				'tab'	=> Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'box_bg_color',
			[
				'label' => esc_html__( 'Box Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'separator'	=> 'after',
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'testimonial_quote_icon_styles',
			[
				'label'	=> esc_html__( 'Quote Icon', 'narihealth' ),
				'type'	=> Controls_Manager::HEADING,
			]
		);
				
		$this->add_control(
			'quote_icon_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial__icon' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'quote_icon_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial__icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		// testimonial_content_typo_styles
		$this->add_control(
			'testimonial_content_typo_styles',
			[
				'label'	=> esc_html__( 'Content', 'narihealth' ),
				'type'	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
			
		$this->add_control(
			'testimonial_text_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__content' => 'color: {{VALUE}};',
				],
			]
		);
			
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__content',
            ]
        );
		
		// client typo
		$this->add_control(
			'testimonial_client_typo_styles',
			[
				'label' 	=> esc_html__( 'Client Name', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_client_name_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__client-name' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_client_name_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__client-name',
            ]
        );
        
        // review-title
		$this->add_control(
			'testimonial_review_title_styles',
			[
				'label' 	=> esc_html__( 'Review Platform Title', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_review_title_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__review-title' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_review_title_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__review-title',
            ]
        );
        
        // review-time
		$this->add_control(
			'testimonial_review_time_styles',
			[
				'label' 	=> esc_html__( 'Review Platform - Time', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_review_time_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__review-time' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_review_time_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__review-time',
            ]
        );
        
        $this->add_control(
			'stars_color',
			[
				'label' => esc_html__( 'Stars Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
                'separator'	=> 'before',
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial__stars' => 'color: {{VALUE}};',
				],
			]
		);
        
		// dots_nav_styles
		$this->add_control(
			'dots_nav_styles',
			[
				'label' => esc_html__( 'Pagination Dots', 'narihealth' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
			]
		);   

		$this->add_control(
			'dots_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-pagination-bullet' => 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_control(
			'dots_border_color',
			[
				'label' => esc_html__( 'Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet::after' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'dots_hover_bg_color',
			[
				'label' => esc_html__( 'Active / Hover Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet-active, {{WRAPPER}} .dtr-swiper .swiper-pagination-bullet:hover' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet:hover::after:' => 'border-color: {{VALUE}}; ',
				],
			]
		);

        $this->add_control(
			'dots_active_border_color',
			[
				'label' => esc_html__( 'Active Border Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'nav_type'	=> [ 'dots' ],
				],
				'selectors' => [
					'{{WRAPPER}} .dtr-swiper .swiper-pagination-bullet::before' => 'border-color: {{VALUE}};',
				],
			]
		);
	
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings(); 
		echo do_shortcode('[dtr_testimonial_carousel slider_col="' . $settings['slider_col'] . '" stars="' . $settings['stars'] . '" nav_type="' . $settings['nav_type'] . '" review_image_display="' . $settings['review_image_display'] . '" limit="' . esc_html( $settings['post_limit'] ) . '" orderby="' . $settings['post_orderby'] . '" order="' . $settings['post_order'] . '"]');
		
	}
}