<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Testimonial Widget
 */
class Narihealth_Testimonial_Single extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-testimonial-single';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Testimonial Single Item', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_testimonial_content',
			[
				'label' => __( 'Testimonial Single Item', 'narihealth' ),
			]
		);

		// testimonial id
		$this->add_control(
			'testimonial_id',
			[
				'label' => __( 'ID of Testimonial to Display', 'narihealth' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'ID', 'narihealth' ),
				'placeholder' => __( 'ID of Testimonial to Display', 'narihealth' ),
				'description' => __( 'Find ID on testimonial edit page. It is slug of testimonial. More details on the testimonial page. Save and refresh for testimonial to be visible in editor', 'narihealth' ),
				'label_block' => true,
			]
		);
        
         $this->add_control(
			'stars',
			[
				'label' 	=> esc_html__( 'Stars', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'separator'	=> 'before',
				'options' 	=> [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
        
		$this->add_control(
			'review_image_display',
			[
				'label' 	=> esc_html__( 'Review Platform Image', 'narihealth' ),
				'type' 		=> Controls_Manager::SELECT,
				'default'	=> 'show',
				'separator'	=> 'before',
				'options' 	=> [
					'show'	=> esc_html__( 'Show', 'narihealth' ),
					'hide'	=> esc_html__( 'Hide', 'narihealth' ),
				],
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label'	=> esc_html__( 'Styles', 'narihealth' ),
				'tab'	=> Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'box_bg_color',
			[
				'label' => esc_html__( 'Box Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'separator'	=> 'after',
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'testimonial_quote_icon_styles',
			[
				'label'	=> esc_html__( 'Quote Icon', 'narihealth' ),
				'type'	=> Controls_Manager::HEADING,
			]
		);
				
		$this->add_control(
			'quote_icon_color',
			[
				'label' => esc_html__( 'Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial__icon' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'quote_icon_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial__icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		// testimonial_content_typo_styles
		$this->add_control(
			'testimonial_content_typo_styles',
			[
				'label'	=> esc_html__( 'Content', 'narihealth' ),
				'type'	=> Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
			
		$this->add_control(
			'testimonial_text_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__content' => 'color: {{VALUE}};',
				],
			]
		);
			
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__content',
            ]
        );
		
		// client typo
		$this->add_control(
			'testimonial_client_typo_styles',
			[
				'label' 	=> esc_html__( 'Client Name', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_client_name_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__client-name' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_client_name_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__client-name',
            ]
        );
        
        // review-title
		$this->add_control(
			'testimonial_review_title_styles',
			[
				'label' 	=> esc_html__( 'Review Platform Title', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_review_title_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__review-title' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_review_title_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__review-title',
            ]
        );
        
        // review-time
		$this->add_control(
			'testimonial_review_time_styles',
			[
				'label' 	=> esc_html__( 'Review Platform - Time', 'narihealth' ),
				'type' 		=> Controls_Manager::HEADING,
				'separator'	=> 'before',
			]
		);
		
		$this->add_control(
			'testimonial_review_time_color',
			[
				'label' 	=> esc_html__( 'Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-testimonial__review-time' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'testimonial_review_time_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector' 	=> '{{WRAPPER}} .dtr-testimonial__review-time',
            ]
        );
        
        $this->add_control(
			'stars_color',
			[
				'label' => esc_html__( 'Stars Color', 'narihealth' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
                'separator'	=> 'before',
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial__stars' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		if ( ! empty( $settings['testimonial_id'] ) ) {
		echo do_shortcode('[dtr_testimonial id="' . $settings['testimonial_id'] . '" stars="' . $settings['stars'] . '" review_image_display="' . $settings['review_image_display'] . '"]');
		}
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {  }
}