<?php
namespace NarihealthAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget
 */
class Narihealth_Video_Lightbox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'dtr-video-lightbox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Video Lightbox', 'narihealth' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}
	
	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	
	
	/**
	 * Register the scripts widget depends on.
	 */
	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );
		wp_register_script( 'venobox', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/venobox.min.js', [ 'elementor-frontend' ], '2.0.4', true );
		wp_register_script( 'dtr-widgets', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/js/dtr-widgets.js', [ 'elementor-frontend' ], '1.0.0', true );
		wp_register_style( 'venobox', NARIHEALTH_ELEMENTOR_ADDONS_URL . 'assets/css/venobox.css' );
    } 
	
	/**
	 * Retrieve the list of scripts the widget depends on.
	 * Used to set scripts dependencies required to run the widget.
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
        return [
			'venobox',
			'dtr-widgets'
        ];
    }
	
	/**
	 * Retrieve the list of styles the widget depends on.
	 * Used to set styles dependencies required to run the widget.
	 * @return array Widget styles dependencies.
	 */
	public function get_style_depends() {
        return [
			'venobox'
        ];
    }

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_video_btn',
			[
				'label' => __( 'Video Button', 'narihealth' ),
			]
		);
		
		$this->add_control(
			'video_btn_text',
			[
				'label' 		=> esc_html__( 'Button Text', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXT,
				'default' 		=> '',
				'placeholder' 	=> '',
				'description'   => esc_html__('Leave blank if need just button without text', 'narihealth'),
				'label_block' 	=> true,
			]
		);
		
		$this->add_control(
			'video_autoplay',
			[
				'label' => esc_html__( 'Autoplay', 'narihealth' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'yes',
				'separator' 	=> 'before',
				'label_block' => true,
				'options' => [
					'yes'	=> esc_html__( 'Yes', 'narihealth' ),
					'no'	=> esc_html__( 'No', 'narihealth' ),
				],
			]
		);
		
		// link
		$this->add_control(
			'link',
			[
				'label' 		=> esc_html__( 'Link', 'narihealth' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> '#',
				'label_block'	=> true,
				'show_label'	=> true,
				'separator' 	=> 'before',
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'narihealth' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Styles', 'narihealth' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'btn_bg_color',
			[
				'label' 	=> esc_html__( 'Background Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors'	=> [
					'{{WRAPPER}} .dtr-video-button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'btn_icon_color',
			[
				'label' 	=> esc_html__( 'Icon Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-video-button::after' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'btn_border_color',
			[
				'label' 	=> esc_html__( 'Border Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-border-animation' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'btn_text_color',
			[
				'label' 	=> esc_html__( 'Text Color', 'narihealth' ),
				'default' 	=> '',
				'type' 		=> Controls_Manager::COLOR,
				'selectors'	=> [
					'{{WRAPPER}} .dtr-video-btn-text' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' 		=> 'btn_text_typo',
				'label' 	=> esc_html__( 'Typography', 'narihealth' ),
                'selector'	=> '{{WRAPPER}} .dtr-video-btn-text',
            ]
        );

		$this->end_controls_section();
	}

		/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$autoplay = '';
		if ($settings['video_autoplay'] == 'yes' ) {
			$autoplay = 'data-autoplay="true"';
		} else {
			$autoplay = ''; 
		}
		?>
        <a class="dtr-video-popup" data-vbtype="video" data-maxwidth="85%" <?php echo esc_attr( $autoplay ) ?>  href="<?php echo esc_url( $settings['link'] ) ?>" aria-label="Video Button"><span class="dtr-video-button"><span class="dtr-border-animation dtr-border-1"></span></span>
        <?php if ( ! empty( $settings['video_btn_text'] ) ) { ?>
        <span class="dtr-video-btn-text"><?php echo wp_kses_post( $settings['video_btn_text'] ) ?></span>
        <?php } ?>
        </a>
        <?php	}
	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function content_template() {
	?>
    	<a class="dtr-video-popup" data-vbtype="video" data-maxwidth="85%" href="{{ settings.link }}" aria-hidden="true"><span class="dtr-video-button"><span class="dtr-border-animation dtr-border-1"></span></span>
        <# if ( settings.video_btn_text != '' ) { #>
        <span class="dtr-video-btn-text">{{{ settings.video_btn_text }}}</span>
         <# } #> 
        </a>
<?php
	}
}